#include <cstdlib>
#include <cstdio>
#include <cmath>
#include <iostream>
#include <iomanip>
#include <fstream>
#include "Globals.h"
#include "CEKG.h"
#include "SWSH.h"
#include "FT.h"
#include "CEKR.h"
#include "CETD.h"
#include "RRGW.h"


int main(int argc, char **argv)
{
  ios::sync_with_stdio();

  if(argc != 4) {
    cerr << "Arguments: 1. l  2. m  3. a" << endl;
    exit(1);
  }
  const int l = atoi(argv[1]);
  const int m = atoi(argv[2]);
  const Real a = (Real)atof(argv[3]);

  
  // Loop over many radii
  Real r = 6;
  for(int i = 1; i <= 95; i++){
	CEKG cekg(PROGRADE, r, a);
	
	// Compute the mode data  
  	SWSH swsh(-2, l, m, a*m*cekg.Om_phi);
  	FT ft(l, m, r, a, m*cekg.Om_phi, swsh.lambda, 1.e-10);
  	CEKR cekr(&swsh, &ft, &cekg);
  
  	// Store the mode and horizon frequency
  	Real wm = ft.omega;
  	Real pm = wm - m*a/(2.*Kerr::rplus(a));
  
  	// Compute the fluxes from the mode data
  	Real EdotH, LzdotH;
  	Real EdotI, LzdotI;
  
  	RRGW *rrgw = new RRGW;
  	rrgw->Flux_Horizon(a, m, swsh.lambda, wm, pm, cekr.ZH, EdotH, LzdotH);
  	rrgw->Flux_Infinity(a, m, swsh.lambda, wm, pm, cekr.ZI, EdotI, LzdotI);
  
  	cout << r << " " << EdotH + EdotI << endl;
	
	r += 1;
   }
  
  
}

