(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    145079,       3068]
NotebookOptionsPosition[    137771,       2946]
NotebookOutlinePosition[    138168,       2962]
CellTagsIndexPosition[    138125,       2959]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Notebook to compare output of Gremlin to the Mathematica BHPToolk packages\
\>", "Title",
 CellChangeTimes->{{3.799435426129154*^9, 
  3.799435440638823*^9}},ExpressionUUID->"98738028-b722-46dd-a601-\
c344155c524b"],

Cell["\<\
In this notebook we will compare the output of the BHPToolkit code Gremlin \
and the BHPToolkit Mathematica packages SpinWeightedSpheroidalHarmonics, \
KerrGeodesics, and Teukolsky\
\>", "Text",
 CellChangeTimes->{{3.799472240819045*^9, 
  3.7994722862005663`*^9}},ExpressionUUID->"ccab6398-4aba-4ca7-810d-\
52534794e246"],

Cell[BoxData[{
 RowBox[{"<<", "SpinWeightedSpheroidalHarmonics`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "KerrGeodesics`"}], "\[IndentingNewLine]", 
 RowBox[{"<<", "Teukolsky`"}]}], "Input",
 CellChangeTimes->{{3.799430192285919*^9, 3.799430197078272*^9}, {
  3.799430271510634*^9, 3.79943027868722*^9}, {3.799430351879752*^9, 
  3.799430355265524*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"a2ce0865-9be5-41cd-9d78-8b8b23bb3143"],

Cell[CellGroupData[{

Cell["Examining the output of Circ_Eq", "Section",
 CellChangeTimes->{{3.799473193350724*^9, 
  3.799473200312703*^9}},ExpressionUUID->"1e57007e-8a08-40ed-9499-\
25292743807d"],

Cell["\<\
To run this section you will first need to run `Cirq_Eq` to create the files \
needed below. For instnace `./Circ_Eq 10 0.9 1 2 2 r10a0.9` will create the \
file below with the (2,2)-mode result in it. Let\[CloseCurlyQuote]s look at \
the datasets in the HDF5 file.\
\>", "Text",
 CellChangeTimes->{{3.799473211129119*^9, 3.799473302373444*^9}, {
  3.799473332411936*^9, 
  3.7994733385419493`*^9}},ExpressionUUID->"86d5b6dd-fce0-4b36-bcdd-\
e505136f5f56"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "SetDirectory", "[", 
   "\"\</Users/niels/BlackHolePerturbationToolkit/Gremlin/bin\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Import", "[", 
  RowBox[{"\"\<r10a0.9.h5\>\"", ",", 
   RowBox[{"{", "\"\<Datasets\>\"", "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7994733126443977`*^9, 3.799473317685369*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"0532d9d7-6ea3-4947-841a-29224e07df09"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"/indexrange\"\>", ",", "\<\"/modes/l2m0\"\>", 
   ",", "\<\"/modes/l2m1\"\>", ",", "\<\"/modes/l2m2\"\>", 
   ",", "\<\"/modes/l3m0\"\>", ",", "\<\"/modes/l3m1\"\>", 
   ",", "\<\"/modes/l3m2\"\>", ",", "\<\"/modes/l3m3\"\>", 
   ",", "\<\"/params\"\>"}], "}"}]], "Output",
 CellChangeTimes->{{3.7994733134128103`*^9, 3.799473318061564*^9}, 
   3.799479676666621*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"ce9ee112-7053-4034-bcdf-bcc246420191"]
}, Open  ]],

Cell["Let\[CloseCurlyQuote]s look at the orbital parameters.", "Text",
 CellChangeTimes->{{3.799473342324293*^9, 
  3.799473356947191*^9}},ExpressionUUID->"e0bc3f5b-3ec2-4f67-af4f-\
053d3cddb66d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "r0", ",", "a", ",", "E0", ",", "L0", ",", "\[CapitalOmega]\[Phi]"}], 
   "}"}], "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<r10a0.9.h5\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Datasets\>\"", ",", "\"\</params\>\""}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.799427881310907*^9, 3.7994279034711227`*^9}, {
  3.79942795216157*^9, 3.799427960811989*^9}, {3.799428173204818*^9, 
  3.799428176239773*^9}, {3.799430223361477*^9, 3.799430237140143*^9}, {
  3.7994733109291277`*^9, 3.799473320745619*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"ef018f77-ca6c-41b3-8d69-ef1a2c963645"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10.`", ",", "0.9`", ",", "0.9522402386495983`", ",", "3.457299296190151`", 
   ",", "0.030747682224285464`"}], "}"}]], "Output",
 CellChangeTimes->{3.799427904227303*^9, 3.799427961177887*^9, 
  3.79942817677076*^9, 3.799430237488566*^9, 3.7994722884087753`*^9, 
  3.799473321300703*^9, 3.799479676761998*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"beb09532-ca62-4f4f-bb39-b0b54da9f388"]
}, Open  ]],

Cell["\<\
These should match the results from the KerrGeodesics package\
\>", "Text",
 CellChangeTimes->{{3.7994733638994904`*^9, 
  3.79947337152738*^9}},ExpressionUUID->"9f0cb153-e2b9-4ae3-9f38-\
c2ae04d4628a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"KerrGeoFrequencies", "[", 
  RowBox[{"a", ",", "r0", ",", "0", ",", "1"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"KerrGeoConstantsOfMotion", "[", 
  RowBox[{"a", ",", "r0", ",", "0", ",", "1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.799427978955916*^9, 3.799427993278973*^9}, {
  3.7994302860814123`*^9, 3.799430297946204*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"8dd59a04-f7cc-4b17-b58b-2109a0b47a53"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[CapitalOmega]\\), \\(r\\)]\\)\"\>",
     "\[Rule]", "0.02388412172230022`"}], ",", 
   RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[CapitalOmega]\\), \
\\(\[Theta]\\)]\\)\"\>", "\[Rule]", "0.029338799769524564`"}], ",", 
   RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[CapitalOmega]\\), \\(\[Phi]\\)]\\)\
\"\>", "\[Rule]", "0.03074768222428547`"}]}], 
  "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{
  3.799427993540955*^9, {3.7994302901389093`*^9, 3.799430298213832*^9}, 
   3.799472289144759*^9, 3.799479676773838*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"cd84a8e7-2c60-479d-bca8-d5ae7327fa76"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"\[ScriptCapitalE]\"\>", "\[Rule]", "0.9522402386495982`"}], 
   ",", 
   RowBox[{"\<\"\[ScriptCapitalL]\"\>", "\[Rule]", "3.4572992961901505`"}], 
   ",", 
   RowBox[{"\<\"\[ScriptCapitalQ]\"\>", "\[Rule]", "0"}]}], 
  "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{
  3.799427993540955*^9, {3.7994302901389093`*^9, 3.799430298213832*^9}, 
   3.799472289144759*^9, 3.799479676780827*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"c052eafe-e4e5-4456-bbcf-453bff821f73"]
}, Open  ]],

Cell["Let\[CloseCurlyQuote]s now look at the data for a particular mode.", \
"Text",
 CellChangeTimes->{{3.799473382080924*^9, 
  3.7994733887058887`*^9}},ExpressionUUID->"eb4a6526-2368-4911-bdf0-\
e1a58b13f817"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"l2m2G", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<r10a0.9.h5\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"\"\<Datasets\>\"", ",", "\"\</modes/l2m2\>\""}], "}"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.799430176447475*^9, 3.79943018690744*^9}, {
   3.799430827547641*^9, 3.799430828195629*^9}, 3.799430983504468*^9},
 CellLabel->"In[9]:=",ExpressionUUID->"c8f01f6b-13f6-46a9-8832-0d59c304e29f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.6318282369200654`", ",", 
   RowBox[{"-", "0.000993054450703186`"}], ",", "0.000268886926148985`", ",", 
   
   RowBox[{"-", "0.0011822961295979637`"}], ",", 
   RowBox[{"-", "0.00035634078507083686`"}], ",", "6923.437625191935`", ",", 
   "349.5375307198729`", ",", "3029.5356940181346`", ",", 
   "586.2466637736751`", ",", "8719.118964170915`", ",", 
   RowBox[{"-", "2411.288500855634`"}], ",", 
   RowBox[{"-", "1202.66929017321`"}], ",", 
   RowBox[{"-", "339.16068556497424`"}], ",", "0.000022273000551180475`", ",", 
   RowBox[{"-", "5.983679213383308`*^-8"}], ",", "0.0007243798211752226`", 
   ",", 
   RowBox[{"-", "1.9460586231300435`*^-6"}], ",", 
   RowBox[{"-", "0.004861729254364484`"}], ",", "0.000013061117748186136`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.799430187497809*^9, 3.799430829496871*^9, 
  3.799430984449697*^9, 3.7994722926702137`*^9, 3.7994796768552217`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"84251bac-173b-4c51-a4fb-c32fa8499f49"]
}, Open  ]],

Cell["\<\
As per the documentation, the first entry is for the spin-weighted spheroidal \
eigenvalue.\
\>", "Text",
 CellChangeTimes->{{3.799473394196433*^9, 
  3.799473410126061*^9}},ExpressionUUID->"5e224812-56d7-42d7-9177-\
1e0ed892ca70"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"l2m2G", "[", 
  RowBox[{"[", "1", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SpinWeightedSpheroidalEigenvalue", "[", 
  RowBox[{
   RowBox[{"-", "2"}], ",", "2", ",", "2", ",", 
   RowBox[{"a", " ", 
    RowBox[{"(", 
     RowBox[{"2", " ", "\[CapitalOmega]\[Phi]"}], ")"}]}]}], "]"}]}], "Input",\

 CellChangeTimes->{{3.799430199520865*^9, 3.799430257362384*^9}, {
   3.799430834803397*^9, 3.79943083715061*^9}, 3.799430981997623*^9},
 CellLabel->"In[10]:=",ExpressionUUID->"bcff1c4c-e04b-43c5-a7a6-e9239f7196f5"],

Cell[BoxData["3.6318282369200654`"], "Output",
 CellChangeTimes->{{3.799430251426408*^9, 3.799430257839191*^9}, 
   3.799430837445342*^9, 3.799437829777136*^9, 3.799472293430772*^9, 
   3.799479676869259*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"8c1ddc38-bee4-4c94-a7f7-12d224927aee"],

Cell[BoxData["3.631828236920063`"], "Output",
 CellChangeTimes->{{3.799430251426408*^9, 3.799430257839191*^9}, 
   3.799430837445342*^9, 3.799437829777136*^9, 3.799472293430772*^9, 
   3.799479676946102*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"e2c2b8db-8727-4d5e-9c5e-91e34c0be388"]
}, Open  ]],

Cell["\<\
The other entries relate to the solution of the Teukolsky equation. Let\
\[CloseCurlyQuote]s solve that using the Mathematica packages and compare to \
Gremlin\[CloseCurlyQuote]s results.\
\>", "Text",
 CellChangeTimes->{{3.799473417399898*^9, 
  3.799473441694564*^9}},ExpressionUUID->"c73ac5df-fd18-4be2-a6a3-\
ca1cbf9c8969"],

Cell[BoxData[
 RowBox[{
  RowBox[{"orbit", "=", 
   RowBox[{"KerrGeoOrbit", "[", 
    RowBox[{
     RowBox[{"SetPrecision", "[", 
      RowBox[{"a", ",", "30"}], "]"}], ",", 
     RowBox[{"SetPrecision", "[", 
      RowBox[{"r0", ",", "30"}], "]"}], ",", "0", ",", "1"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.799430394991132*^9, 3.799430413303424*^9}, {
  3.7994305637772217`*^9, 3.799430570785286*^9}, {3.7994307153712797`*^9, 
  3.7994307289917593`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"7da7b80b-e208-44eb-9c5d-90510f77f92a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"l2m2T", "=", 
   RowBox[{"TeukolskyPointParticleMode", "[", 
    RowBox[{
     RowBox[{"-", "2"}], ",", "2", ",", "2", ",", "0", ",", "0", ",", 
     "orbit"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.79943041532975*^9, 3.799430415745098*^9}, {
   3.7994305474956512`*^9, 3.799430574618329*^9}, 3.799430842755628*^9, {
   3.799430986789867*^9, 3.799430988465057*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"c459596b-9c5a-4530-af12-5d23cb65b910"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"l2m2T", "[", "\"\<Fluxes\>\"", "]"}], "\[IndentingNewLine]", 
 RowBox[{"l2m2G", "[", 
  RowBox[{"[", " ", 
   RowBox[{
    RowBox[{"-", "6"}], ";;", 
    RowBox[{"-", "3"}]}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7994305761075068`*^9, 3.7994305813577223`*^9}, {
  3.7994306715316753`*^9, 3.7994307032179403`*^9}, {3.799430846040741*^9, 
  3.7994308820721273`*^9}, {3.799430991425111*^9, 3.799430995125525*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"87e87705-4683-4ed9-ae05-568eeee0faa5"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"Energy\"\>", "\[Rule]", 
    RowBox[{"\[LeftAssociation]", 
     RowBox[{
      RowBox[{"\<\"\[ScriptCapitalI]\"\>", "\[Rule]", 
       "0.00002227300055118049933992902400247393`18.394080745626674"}], ",", 
      RowBox[{"\<\"\[ScriptCapitalH]\"\>", "\[Rule]", 
       RowBox[{
       "-", "5.9836792133833631889705375718`18.423985338701062*^-8"}]}]}], 
     "\[RightAssociation]"}]}], ",", 
   RowBox[{"\<\"AngularMomentum\"\>", "\[Rule]", 
    RowBox[{"\[LeftAssociation]", 
     RowBox[{
      RowBox[{"\<\"\[ScriptCapitalI]\"\>", "\[Rule]", 
       "0.00072437982117522337634770667032492301`18.394080745620382"}], ",", 
      RowBox[{"\<\"\[ScriptCapitalH]\"\>", "\[Rule]", 
       RowBox[{
       "-", "1.94605862313006130372868300907883`18.423985338694326*^-6"}]}]}],
      "\[RightAssociation]"}]}]}], "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{
  3.799430581589264*^9, 3.799430673229767*^9, 3.799430703422426*^9, 
   3.799430735339405*^9, {3.799430847009639*^9, 3.7994308822935143`*^9}, {
   3.799430993654194*^9, 3.799430995894458*^9}, 3.799437834716284*^9, 
   3.799472295636426*^9, 3.799479678671175*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"f7fdd751-45be-4c87-8bf0-593e91e8f2fa"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.000022273000551180475`", ",", 
   RowBox[{"-", "5.983679213383308`*^-8"}], ",", "0.0007243798211752226`", 
   ",", 
   RowBox[{"-", "1.9460586231300435`*^-6"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.799430581589264*^9, 3.799430673229767*^9, 3.799430703422426*^9, 
   3.799430735339405*^9, {3.799430847009639*^9, 3.7994308822935143`*^9}, {
   3.799430993654194*^9, 3.799430995894458*^9}, 3.799437834716284*^9, 
   3.799472295636426*^9, 3.799479678674698*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"8f9eb1dc-09a2-4edb-b870-030d09f4f0c8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"amps", "=", 
  RowBox[{
  "l2m2T", "[", "\"\<Amplitudes\>\"", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"l2m2G", "[", 
  RowBox[{"[", 
   RowBox[{"2", ";;", "5"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.799431672871736*^9, 3.799431686071574*^9}, {
  3.799431812385188*^9, 3.79943182554604*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"32cc2fc0-84ce-4612-bf5a-783c872c95c0"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"\[ScriptCapitalI]\"\>", "\[Rule]", 
    RowBox[{
    "0.00099305445070318656643205409402353278`18.733107444182814", "-", 
     RowBox[{
     "0.00026888692614898577837659081604705543`18.364162021255165", " ", 
      "\[ImaginaryI]"}]}]}], ",", 
   RowBox[{"\<\"\[ScriptCapitalH]\"\>", "\[Rule]", 
    RowBox[{
    "0.00118229612959796809186255789952953457`18.7639638163717", "+", 
     RowBox[{
     "0.000356340785070836251974587856249004`18.436257403074297", " ", 
      "\[ImaginaryI]"}]}]}]}], "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{{3.799431680191997*^9, 3.799431686418777*^9}, 
   3.799431826031747*^9, 3.799437835675859*^9, 3.799472298530739*^9, 
   3.799479678754361*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"a70c34eb-71fd-48c6-9fef-1b67d691ce97"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.000993054450703186`"}], ",", "0.000268886926148985`", ",", 
   
   RowBox[{"-", "0.0011822961295979637`"}], ",", 
   RowBox[{"-", "0.00035634078507083686`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.799431680191997*^9, 3.799431686418777*^9}, 
   3.799431826031747*^9, 3.799437835675859*^9, 3.799472298530739*^9, 
   3.79947967875718*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"95b666bf-737f-478e-932d-eca96f9baada"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"l2m2T", "[", "\"\<RadialFunctions\>\"", "]"}], "[", "\"\<In\>\"", 
   "]"}], "[", "10", "]"}], "\[IndentingNewLine]", 
 RowBox[{"l2m2G", "[", 
  RowBox[{"[", 
   RowBox[{"6", ";;", "7"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.799431565630855*^9, 3.79943173558458*^9}, {
  3.799431769523529*^9, 3.799431794870026*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"c414cedd-f8b4-4260-b827-226760eed17f"],

Cell[BoxData[
 RowBox[{"6923.43762519192328038975182069609600192778`20.056953058082286", 
  "+", 
  RowBox[{
  "349.53753071987782950747983800995712415354`18.744887062722242", " ", 
   "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.799431624416872*^9, 3.799431668424933*^9}, {
   3.799431701546401*^9, 3.7994317359167347`*^9}, {3.799431771116271*^9, 
   3.799431795313376*^9}, 3.799431837290498*^9, 3.79943783646452*^9, 
   3.799472299354597*^9, 3.799479678854794*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"819c5761-82f0-49e9-934a-d126f3b5f405"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6923.437625191935`", ",", "349.5375307198729`"}], "}"}]], "Output",\

 CellChangeTimes->{{3.799431624416872*^9, 3.799431668424933*^9}, {
   3.799431701546401*^9, 3.7994317359167347`*^9}, {3.799431771116271*^9, 
   3.799431795313376*^9}, 3.799431837290498*^9, 3.79943783646452*^9, 
   3.799472299354597*^9, 3.7994796788571863`*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"ada2e496-3099-4d8c-b4a1-23c499dcdefe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"l2m2T", "[", "\"\<RadialFunctions\>\"", "]"}], "[", "\"\<In\>\"",
     "]"}], "'"}], "[", "10", "]"}], "\[IndentingNewLine]", 
 RowBox[{"l2m2G", "[", 
  RowBox[{"[", 
   RowBox[{"8", ";;", "9"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7994318613767757`*^9, 3.799431865877708*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"8b378193-0e0e-4f22-85b9-ba1584ad7cb6"],

Cell[BoxData[
 RowBox[{"3029.53569401812974814350441004727960269526`19.52659630325822", "+", 
  RowBox[{
  "586.24666377367623733109761381675770555222`18.821227473730858", " ", 
   "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.7994318617464457`*^9, 3.799431866109261*^9}, 
   3.799437838531211*^9, 3.799472300061371*^9, 3.7994796789882717`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"d0bdee9e-1bad-42e2-bda4-785065c6c4f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3029.5356940181346`", ",", "586.2466637736751`"}], "}"}]], "Output",\

 CellChangeTimes->{{3.7994318617464457`*^9, 3.799431866109261*^9}, 
   3.799437838531211*^9, 3.799472300061371*^9, 3.799479678990906*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"3117fb96-8203-4363-a1f6-14b1dc6f8274"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"l2m2T", "[", "\"\<RadialFunctions\>\"", "]"}], "[", "\"\<Up\>\"", 
   "]"}], "[", "10", "]"}], "\[IndentingNewLine]", 
 RowBox[{"l2m2G", "[", 
  RowBox[{"[", 
   RowBox[{"10", ";;", "11"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.799431842996902*^9, 3.799431854651516*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"c6b04ef8-8f1e-45ad-87d5-465cb104f7af"],

Cell[BoxData[
 RowBox[{"8719.11896417092347309427876803169902037217`20.257202393509843", 
  "-", 
  RowBox[{
  "2411.28850085561722179371696959276773758693`19.666695875464402", " ", 
   "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.799431839359323*^9, 3.799431854919199*^9}, 
   3.7994378392541723`*^9, 3.799472302604261*^9, 3.799479679185052*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"7c46805b-eb92-41aa-97a2-0f8e5f87206f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8719.118964170915`", ",", 
   RowBox[{"-", "2411.288500855634`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.799431839359323*^9, 3.799431854919199*^9}, 
   3.7994378392541723`*^9, 3.799472302604261*^9, 3.799479679187615*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"9e92c858-acc3-4eaa-a15c-9910cd3f622b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"l2m2T", "[", "\"\<RadialFunctions\>\"", "]"}], "[", "\"\<Up\>\"",
     "]"}], "'"}], "[", "10", "]"}], "\[IndentingNewLine]", 
 RowBox[{"l2m2G", "[", 
  RowBox[{"[", 
   RowBox[{"12", ";;", "13"}], "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.799431877803741*^9, 3.79943188176381*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"b2631fe9-4782-4e5d-a810-9d8f24f05ad9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "-", "1202.66929017319813381055736046044615572275`19.363172972785495"}], 
  "-", 
  RowBox[{
  "339.16068556496944079817088986115858940925`18.79666281567883", " ", 
   "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{3.799431882022746*^9, 3.7994378400904627`*^9, 
  3.7994723034217777`*^9, 3.79947967930796*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"f1acdad9-8309-4c92-aa4c-bcb63138a541"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1202.66929017321`"}], ",", 
   RowBox[{"-", "339.16068556497424`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.799431882022746*^9, 3.7994378400904627`*^9, 
  3.7994723034217777`*^9, 3.799479679310712*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"335d667f-353b-4fac-9758-73de5d7fefbc"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot the waveform", "Section",
 CellChangeTimes->{{3.799435450551054*^9, 
  3.7994354545208073`*^9}},ExpressionUUID->"13832df6-7e2a-4393-90f9-\
cc1f9eb54ff3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "SetDirectory", "[", 
   "\"\</Users/niels/BlackHolePerturbationToolkit/Gremlin/bin\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"wave", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<r2.4a0.9.wave\>\"", ",", "\"\<Table\>\""}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.799435455462069*^9, 3.799435465794981*^9}, {
  3.7994377471988707`*^9, 3.799437761707965*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"67a1bef5-8c06-463e-8b16-1a513da0c55d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"wave", "[", 
      RowBox[{"[", 
       RowBox[{";;", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "2"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"wave", "[", 
      RowBox[{"[", 
       RowBox[{";;", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotTheme", "\[Rule]", "\"\<Detailed\>\""}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "800"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "18"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799437762246307*^9, 3.799437809303388*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"d14b9fd5-6ab1-48a9-a338-1bcf0405ed08"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHk8VevbxoXSoFIoSiSZ53m2L9ueFGnQoOloIJ3m1EkjkiaFolOaVUiD
FCqlTCmVIbNNmW0RURqE9Do/93rXPz4++1nfda1rrXXf93Oprt4y30tcTEzs
+zAxsf/+Mods3a3o7K/1rPNR/x2pLB21Y6l/Gpn/X7MM7L9ftyuoZ5n+7yhh
nduZ8nbTfeZ3IYu7cu+Y8JP1rCFaHevlne39t1cz6xtZz44bLywzqmd5/+8Q
seT2+qjo9tTR+a2s5beKJ1U8rmPl5/13tLPOjzrsO9a3jnhdrDHrnZKlNZn1
X1gb181xtbpVS/xuVlKbb4p8Xw2d/431JmOY/grHGrreD1Z5nFJEzv4PxOth
dawZnj72/nvi/WKdFqvq+1VdTbw+1vcHluy5f6qI18+qal6mUj61ingDLMW9
zUZzTITEE8MIxUdHfJ0qab0YJDzP2v1yqyD+MOidNZE/sqSczhfHOrV9kQ9X
lNH1JNCfNidsomcp8SThLuPaJu9ZQjxJ7PhzTV57ZTHxhkN3LM8iemkR8UYg
fKrZrayF74gnhdXGbUv3Xikg3kjI70lKW3Uqj3gjoTb55575gW+INworpv9c
47wll3ijcUeHa6e27CXxxuCjx59L1zkviCcNCedQnd26WcSThtyRGRHs8RnE
G4vugaZI9dqnxBuHiDFruO1nHxFvPHbYVB3s5CcRTwbCB8vcLr2/S+tlMDp5
hpSfXAzxZfDzhnCF0sZzdP4E/KP16PZf4nvoehMQ+dLzjrTFkfQh3kTsjY7u
c265lD7EmwirIy37Go1vpg/xJiI+Kag2IzsxfYgni9BayR1Ru1PSh3iy+G7o
7HXc+gnx5OBzX+71YvF04skhdLLSFrvWTOLJYdLrsTvHub8gnjwU89UTIzNe
Ek8eb8t7Z0TrvybeJPSW3p/VGvWWeJMw6utv5RGSBcSbhPmXxq21N39HvMlQ
SQg5Ve1VRLzJmN1lFzc+oph4Cki5/en2iLQS4inAWmtVbEdtKfEUUKMQ97Lr
dxnxFBHMllRiy1cQTxEte/sjFdUriTcFCdGGCo/0hMSbAj/ZihPrdKuINwUD
g2oPTa8m3lS8nzbSf+eY98SbirxSf+OHn94TTwlBIzWXFGd8IJ4S4vYXWPkc
ryGeEi5OSvuoK6gl3jQ8TXE53PirlnjTEKIf75/iVkc8ZXyx6ktdfLGOeMq4
p6cnK2yoI54yMo6+CmOr1RNPBdUdL37cWFFPPBW82+RnpHC6nnjTsX+Cms2T
DGb9dCyNVEu421pP/Om4WmjRoTC2gc4f/D+8Z+tM3Qa63nQsKgjy7HVqIJ4q
kocfKs9e3EA8VVy2Nq+/6d1APFU4vW4qLdjK8FSxmbf98qJ/GJ4q3MOvnFy+
i+HNQH38qbgfvgxvBlRHZw4328jwZuBce6uZkifDm4GJG5f/SXBjeDOwXO2D
TqMNw1ODatZatzhVhqcG7goZi3oJhqeGw8rGezbXM36p4YF2//OZT+qJpwa+
y/m5xScZ/2ZC/q5ljsNyxr+ZSJYp2aGnzvg3E23XLzUt+VhHvJnQxRuHAzHM
85oJycTlb9yXM89XHcbaUT8jpOuIp46g9hFTP26oJZ46fo1WmuKZWEM8dZzx
7raSFn0gnjou7FsPX+kPxNNA8B1ZOx2198TTwHrxq82l2tXE04CeSkS59vQq
4mkg/ey6N93DhcTTgGXrxkey1RXE08S+a7x9B6+UE08TCr9uP5y3oIx4mjig
dWT43R8lxNPEpbgzl4THiomnCZWjR0IsxxYRTwt3JR0t/MULiacFFbnOZSPz
mfqghTkhiWeX780lntZgPXu5uXdcDvG00C+98tbRY5nE08YZRfXL14RPiacN
82mjXHfuTCaeNtZX5cdMLYsnnjZeXU2c7PItknjaUJzMM8jeeYjqsw7uRbZm
SLXeoPqrgyly8+z6tzygeq0D1QzTT+X7nlA91sHPU8siNs/OpPqtA4ePwju9
y3OIp4uPjeHZk7a9Jp4uVuR3LawPzieeLnbuLtj2Ou8d8XRhvX5nPqusmHi6
MHt7zyi0mumXehA/aL2nv6aceHo4zPNuaqipJJ4eqpLY7XFVVcTTw+Vp8jee
F70nnh4icn7zY7NriKeP1pV5tt2L64inD5Pxbl5Ss5n5RR8LtRsUhTYNxNPH
lrtwMNFsJJ4+ltqN2Fk9vol4BigcGWB7/lsT8QygMDDtgkFZM/EMMIInMW3+
fRHxDGAVM1km5WgL8QwgO+zcvt9LPxLPEEXlu8xeaLYSzxCHbFeVRH5uJZ4h
tBdMKmxLaCOeIWLmbttl7POJeIaY7tIsyFJsJ54RTvkpBzZltQ+tVzTCKzVx
lfzVHcQ3gl7RwJ3LPR1D57sY4Y21tOP6oM90PSPoLqv6S0+8c4gXYIQTywNN
Knw76fpG0PeRKZtV0TnESzKCwooapQT5LtJjhJYsgeHfll1DPJERJuSqh9rN
7SJ9xng2zPt50F9dpM8Yur8qV1xd20X6jBH+rOb3l5XEczHGWpsde2pciedt
PFRvjYgXYAy9cesOmEsRL8oY3NLWZqVoRp8xVELXcrMVOkmfMZa+int4fAfd
r8gYlzyW62cmdZA+E2Ts9/siLGP8M8FCyc+G26o+kT4TbPQdmemW2Ub6TKDK
mpq6+TjzvEwwd9PWGb3m9HwDTDDN/UjgghfM+2CCs9kRB2UtmkmfCTYY/o4d
c4J530zw2ElZif+K3k+RCQ5FttbLF9eSPlPEf1dru9VcTfpM4XhW3vBpXgXp
M8WcXuOLqiE0b7qYonLzNif2rALSZ4rpWQnvMx3o+w0wRcWT3W7H+x6RPlO0
/26USQqLJH2mWC/bMftB822qJ6aYETlfN+5cxlD9EQ3y7wX/Hcl6Q/XKDJJN
s2/WddF8o2gG4bv8AaQy9dUMqwTnko5urx7iuZih5t4Kc50xTP83g6pUQLCm
G/W3ADNYVuIvlYNNVN/M4MeSHTE6WjTESzLD2esbLfpufiR9Zvh0atVWrbNt
pM8MT+UezOnyaSd95oARP6x26mfSZ47gb1u+PrzbSfrMoZux64JlaBfpM8d2
hby/VE2/kD5z8JWP6hW/+EL6zPHfdH6L/ZX0maNP+XuF7p2vpM8cyU1fkvvF
ukmfOV7W590ToZv0mSN8/aYp1Ru6SZ8F2o8r1ncEdpM+CyzsMU3zCOomfRZI
iRn3dc9W4rkM/j5n76wCZ+J5W+C7zy3N7vHEC7DAZdYm97hsRp8FDgW21GR7
Mfos0J2rIm338wvps4B2kqOG4m66X5EFuN4GW3e3d5E+SyjHP+8Omd9F+iyh
4Xvk5jQPxj9LiN828z39s4P0WWJ7X3OEfFA76bPEurSRCa4DbaTPEj+Slhxv
2tBK+izRx12bdKCghfRZIjlWedwjLRHps0TDHNPPk/c3kT5LeBqcS5hUwMxD
VjjoLzZynDLNO4pWKHpm/9y3pob0WeHaywJ17yPM+2dF9b+S9Fkh9qLhj5X9
paTPCrfSU6eYFTLzuhXe3qjv3L4xn/RZ4cwGr2mt616RPitE5iwZpngmk/RZ
IUjuQLRB5yPSZ42za/jT+gW3SJ81tvdaXYv0PUz6rKGyY/+HL6yL9P1ao21J
i4zKzkT6fq3xW9Xn9G7PVPp+rbFzmtvWRa3Mfs0aFRdWqySIXtD3a428pube
o/G5VF+skTtXUvOUaR7VF2uo3Xs2PPdwIdUXG0hp+41OnV9E9cUGwesLEqVe
F1N9scHSqYrnozVLSd/g+uuCu6ItZaTPBrauYyRsr5eTPhsUFrl9GJbN7J9t
cLfhY/C/7ypJnw3eJIzn8fOFpM8GqecPf3V7QvtzkQ0Cl1Snlp2rJn22KHk9
cmXjetrvK9riyR0/oZfBB9Jni4wRnKO6LR9Iny2iiszy6yKZ/MAWP8OCP8pY
UT0NsMWjx6qq6kW1pM8WMiGrJUyNaF5IskXOrmdhA9uZPMMWKZKFvr2JdaTP
FhoTdDuU25h8ww6Xa/ZuXqxMeYqiHUqipocFuzL5iR1cR9vfCdxVT/rscGuD
wHLaRWYesYOWnouN+lPKXwLswLnY3bO6lMln7LBbuu3hlRbiJdnhzlkbtZhv
xMuzw+DwFMvqY/qHHQ7/MycJfUyeYw/BAvso/2+MPnsct9goVi1i9NljIkfz
jE0xo88epZI/7MMeMvrsIbNsj1lZBKPPHiX20Scn/s3os4fzaeOjHtaMPntM
EHetfTmM0WePvUvDpIOyGf/sUbs67HzGAcY/BxRmhi5NM6V8SNEBj2xTOH45
TD7kAEn+Y/+pCrWkzwFqtyckSnsyz9cBj9fFGYldpnwowAFCPKlMLmbyIQes
UGjldgxQPpTkgB1qRVu3qFWTvkGeXqGWuCPz/jlgo3+W2bolTD7EQpiL3pnl
f1eSPhaWDpgUnNnF9F8W/hSuep4WUE76WJh3b1blpsPM98HCPUHcKItjNO8G
sLCp6LFGxLES0sdCvMrxx51H6HtLYuG1j0FgzKEi0seC5ues6b3+70gfC2+v
VtVxvjH5ELCqsXfXfhHlQ9LAnuayyPRyyocUgY3724+NyqF8SAPomTe2z/4+
kw8BrlXuH9QuUD4E4ERUq8Tmg5QPuQD/CPbmp3lTvfEADHoOJDuHpdH9Af6l
7dfWOj8e4vkCopqxSfW9lA8FAAdfCFXTuPeGeCcGf+e99ZQJjKX7BxKbZs+8
6XJhiBcL2HpMGH6u6CD5ASzXTBbrWxg4VE8zBu/nVJm2d+d5qr+AX5V7mvyD
2KH6KgR6BzzMxcQTqR4DIS93pSg/TB6qt92Amtf4D4E7Uqk+O6I94nRpj+3z
IZ60I3YIL48PDs6keu2ICVMyX37vzB7iaThCKc6kXLD8JdVvR9zgvlJZ9Dp3
iAdH9FxruFFm/pb6jSP8vVO8vK7mD/E8HJGkv/JIjsQ76j+OmLjoedYHs6Ih
nq8jijQaRt5dTflQgCP2TJg4bvWJkiHeCUewzM7pat0vpf40uH7Dbwf9d7R/
jXVE39F4h+iPNH8lOcJcYljFk1+0/81whPuMpsmp4sz+2BFSzzp6msVp/yx0
xOvMCc5Rv6rIP0cIhv1WtBZRXtTtiJb2BRy7XCYfYmPYj6J43Su0f5dmI/JR
bsP1v2l/r8hGmW5GsbsO7f812DC888/NYTVMXsTG7rGJ3Ew25Qdg48quNY6r
wilfcGFj3xTRk9oKyh882PjX+JsDR5HJJ9hYPeA1/7I75Re+bIxv9Lcbfpzy
jQA2pG4kHTyTSvnHCTYWmoi5b2tk8hE2ci9mxTyXovwklg2eyOJwjAblK0mD
15ueK3IDzRsZbAj8jINa3Jl8ho2xY/6YRq6l/EbIRlue/cx9W4gnYmPWn/f1
GTuJ182GmHHCCv//z4ecsD0+Rq5wB/GknZDicVsvYxPxFJ2w9Gebw7LVxNNw
QnR90Mno+Uz+44Sin6MWhTgQD04oFpzZPlKDeC5OMJfN8hAbRTwPJ4TJR++f
18L454Qll0QGJUx+5uuEFum94e5nGP+cIDe8l3N5LeOfE4JeFCX6GjD+OcGH
HfHi9Fea52OdcGlGkfzDRMp/kpyg3Pt50b8+9HwznBA7YNTTpsjkR06Yolsu
X3mU8kKhE04aXd0eV1hD/jlhVH99S7oUzXPdTng2KUo91ojJhzgwW5zGb3d+
T/5xsLlsSqfpgmryj4O18edzjFzofdbgQOjf4x5vJiT/OPjh0nx9rzTlp+Bg
dIeo+0JJOfnHwftdi5QUjpeRfxw8gOfxyUal5B8HqVfX3KnOKSb/ODinF3E4
fTblQwEcnDrtI7vtUCH5x0GJJN7GL8gj/zjQyTzyyHfEa/KPg4/2h+J4l3PI
Pw52C70SspSyyD8Opow7E+4h9Yz84yC9MuViYTzl30IOpHdOynnhfIf840DA
Tpj07msU+cfBs1ol69y4HdQ/uJh66uLojCXXqH9w8Ubrct61mfepf3CRfVBJ
pscglfoHFz+WXJkccT2D+gcXi2bpJAQnM/2DC3Ve8FWPXJo/Xbj4erDxpOaH
POofXAh/73A97Uf9zJsLy9AlIW6B1P98uXgkG1AlcZTpl1xse+Bz5lsI9dcT
XFz5JRL4naB+HMXFv97xt78cpf4dy4XaY4tfxQHvqX9w0WH7zj3Kl/KhDC7W
zf910suIme+46Ld5e6RPjeYZIRe/2cKYxXIN1G+5SHULFecMaxzidXPh1GL+
z7G2RvKPB82i9+6fC5vIPx4On3xwwPR+M/nHg2/Mr+eyoSLyjwcrKcWJjt4t
5B8PzZl5+musKT8AD3m8ln45qVbyjwf/9fOuNBW0kn88JH15ypkb3kb+8XDh
U1hIzizKK3wHf89ymB39+xP5x8Nd1zV79W+2k388sNcEjr7m3EH+8fBmfOz2
mfUd5B8PW/dM7ny16TP5xwP+enE09PNn8o+HX9clOtavZvIVHr56Z8+1z6W8
SMjDuiJb+a3jmTyIB8M6r8MnTSjv6eZh4+7mPdUuTD7Eh8Dk9q7HKyj/keaj
R3HyuENrmbyIj3usY4WXPImnwUdL6MDZDfOY/IgP61VZPossiAc+9mx3Dcwb
x+RJfExfHRQckUz6PPjIDR9pEmfUSf7x8dL2nxH94XS/vnyoyHx0qSqlfCiA
D8NgqfyEPsY/PqpfvP49bjjlRVF81A9s8kzroucRy4dkxduYuOeU7yUNnu86
oe7bZnq+GXyEWJqE9Q9j8kE+dEXlS+f40fsi5CPLpTr9QXEj+cdHccsAV3di
A/nHx+epklndlsz8LMDaXYGnxUMoD5UWQIb7/qfEbmZeFSBgsbxusn0p+SdA
6NWW4aFPCsk/AXjsZQUxj1+SfwJc9dLMN/rzhPwbXP9tUn7xuqvknwD7n0aF
+SbHUP0TYJnxxPBm2edU/wS4fN9Q6JdI81CAAAL/3RNn6BRR/ROgMvKduMc3
qqdRAqTOONHrn0j1OVaA3JqLy0yW0HyQJEDQQ1FlyFfqRxkC3Ho6NsdPq4nq
nwDDk3okSmeJqP4J4LfBzf/Ooo9U/wQI9GytMHZuo/onwEGZqrSnKkw+5Izw
SIfnBRUd6f8HrLIiEA==
       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mXc8lf3/xyXciuyyt5SRvdd5OVNF826IEhoaWirdqE5DU2lpaGiinU5G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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->18,
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameStyle->Automatic,
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{Automatic, Automatic},
  GridLinesStyle->Directive[
    GrayLevel[0.4, 0.5], 
    AbsoluteThickness[1], 
    AbsoluteDashing[{1, 2}]],
  ImageSize->800,
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 50.}, {-1.219568, 1.240759}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.799437776834775*^9, 3.799437809673051*^9}, 
   3.799479679600115*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"05fe2498-ccd8-4983-b3fa-88e034180211"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exploring the flux", "Section",
 CellChangeTimes->{{3.799476514562479*^9, 3.79947652091951*^9}, {
  3.799477568457238*^9, 
  3.799477582361662*^9}},ExpressionUUID->"3cdc1f2b-6703-47b5-8677-\
ad3891cc2cd7"],

Cell["\<\
Let\[CloseCurlyQuote]s compare the flux to the Schwarzschild PN series for \
the (2,2)-mode\
\>", "Text",
 CellChangeTimes->{{3.799478569161459*^9, 3.799478583561047*^9}, 
   3.799478703565707*^9},ExpressionUUID->"a5d2a645-960b-4a7e-b21e-\
670e2df51fde"],

Cell[BoxData[
 RowBox[{"<<", "PostNewtonianSelfForce`"}]], "Input",
 CellChangeTimes->{{3.799477282286512*^9, 3.79947728748834*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"e1362d04-6095-4b36-90d9-c4fc02e76ece"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PNFlux22", "=", 
   RowBox[{"PostNewtonianExpansion", "[", 
    RowBox[{"{", 
     RowBox[{"\"\<l2m2\>\"", ",", "\"\<Flux\>\"", ",", "\"\<!Spin\>\""}], 
     "}"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7994773914268007`*^9, 3.7994774255584*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"a6155055-7685-4371-8e45-7ceac2977d6c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PNSeries", "=", 
   RowBox[{
    RowBox[{"Normal", "[", 
     RowBox[{"PNFlux22", "[", "\"\<Series\>\"", "]"}], "]"}], "/.", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"1", "/", "r1"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7994774811916027`*^9, 3.799477540995821*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"fdf20be5-f686-4587-a781-9b73ae40afd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fluxData", "=", 
   RowBox[{"Import", "[", "\"\<FluxAtManyRadii.dat\>\"", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.79947652696213*^9, 3.799476546031766*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"5958ba11-4f3a-4648-8314-8be9300d722a"],

Cell["\<\
Note there\[CloseCurlyQuote]s a factor of 2 as the PN series is for the the \
sum of the m=+2 and m=-2 modes, where as we just computed the flux from the \
+2 mode.\
\>", "Text",
 CellChangeTimes->{{3.799478716233276*^9, 3.799478736239904*^9}, {
  3.799478929973359*^9, 
  3.799478942651854*^9}},ExpressionUUID->"6759d3f5-be33-4de4-adec-\
02087f305900"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ListLogLogPlot", "[", 
    RowBox[{"fluxData", ",", 
     RowBox[{"PlotTheme", "\[Rule]", "\"\<Detailed\>\""}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"LogLogPlot", "[", 
    RowBox[{
     RowBox[{"PNSeries", "/", "2"}], ",", 
     RowBox[{"{", 
      RowBox[{"r1", ",", "6", ",", "100"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.799477124969556*^9, 3.79947712613735*^9}, {
  3.799477236571433*^9, 3.7994772430490637`*^9}, {3.7994775446531754`*^9, 
  3.7994775617634478`*^9}, {3.7994776268691683`*^9, 3.7994776288702183`*^9}, {
  3.799477742520093*^9, 3.7994777427762737`*^9}, {3.799477893834259*^9, 
  3.799477894146481*^9}, {3.799477963335951*^9, 3.799477965791235*^9}, {
  3.799478030566424*^9, 3.7994780373712807`*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"ddd89545-0ccd-4a8b-9188-8502e2d03afd"],

Cell[BoxData[
 GraphicsBox[{{{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwtlHk01AscxWVJzOL3m1ciSpIYy4yZ3+9HZPkimkpCOlOh0HOSUcryKFTm
tKkIqfPSriJLJG32b0qb9Iosx9OpF0UqEWXI8nrn9cc999y/770fw+AInxBl
JSWlDT/1nyvPNRtlFYw5dbUlJXqcM0DpOnFR5LxJp0jTl0VvIwwxqmCR0/Vs
Jdhvuf5mxLN5yFK5urP32BRYeY66p5gwQu3VNytKZMrw423Jyz62MXrY7L7d
KVCBoc+SaJw0xsSzTZXa/6iA+fCrFSc7FqD3EZG56j5VUFSyzzrlmmBuRav2
E3018Mg0EKYEm6KBZIWtdr4aGIS2cssIPn6xHZ1wEUyFVbc1x/aW8nHn7tG7
svypgAtcjvl7mOH+dJldvIE6vH5+YoOswwwtSlWnWqeqg+Py1itXfjfH9M6o
eJdhdSi8lNbX9c4cS4oiMgV+0+B+XHJNY6AFPqpziI0unwajImqjRosF9pe+
GE+coQGO07Pvs90tccQiIyE3XAOCiga9PUsskUr5POyMGpC02dyG0hFgw6z+
3kxCE16pz47jxQswba/KndcBmjDQXllm1y5Ao2UnWtZd0QS/Qxx6gBGiwURD
/cJ+TfhcPJ8bnSrEUy2skRyGBdeysjf96BTiOvN0ybM4FkiUqmv99KxQ9uhO
dVMZC+Sz5s4Pd7XCF3eah9oULDjztDzHJcwKv3PKksYYNnzbdsH661ErrBvU
WrVuOxvulsPw4RtW+H+/bLj+VLLRoM0Kqx7a9Zl2siHwguZw+agVXnG+V/dA
lwNzytk1Mn0RtnAOho54ckDqUmzi6CBCTqR4UZOcAwtDVYwdAkToWZjqFnKT
AzvcbztHJYjQ0kHgW/OeA14mVTq9WSIkP03X7tfmQnTinnf5d0To6jtmrebO
hYqvrzOqmkV46fHFP1jRXMBIiYPZVxGGu6RVcS9wwXtbA6ngiPFWf5pwVgMX
RAn2SgK+GGMqvOwXKrgQGnXZrNFV/GufWvAw/vjr3gAxFusV3m5crgULIiUu
ibFinFTyngyM1gLBDs+R1DQxLs0ryjc+rQWVkvsD8/PEWGA/L9T0nhbsWYDt
rnfFyP6tNnbbBy14o3xU2N8mxsGJ8rVydQKUdSuVBf1i9Ao3q/+mS8BffeA7
RZ3CtVlXL8ywIKA2OOfTltkUrnB/UNflQMDUll7XWIrCHfyHIyErCTjVrN89
dymFh8UhHacCCbhlXdu7ZT2FnHDex4PbCYhPXxoTFEXhxw6TvUI5Ab728mUT
ByjU0+nsSc8gwGR63+Ylp6lf/yNgYOGAkdM1CmP4mccyrhOQ9fSLWc89CnOM
lrXTtQTctGkvXtxKoSVpOpD1ggDDVRn20l4KbZ9VnH/whoDY43sHDMcprJiV
eabsCwEHZ/Z15GjRaOi8KTlmggA/2ZGebkMaH7fMH/rBJiG57YtTN0Wjk3TI
31OPhGn85lU5bjS+F86jtvJJkOosE5lIaZxdMNbib0OCr5/8miyURn/17Cw9
NxLG2bHSmB008nqwtsCHBLla8hK3QzTaiz0OcANJ8Mm2fN6RRSPf02i62xYS
2nTDfBwLaIwqKU722knCsOUaNVkFjYv3xI2LDpBwvn3rjY319C/+kGCbrN/K
/5vGkDM5yvHnSdhU9ware2mUdwWndBWSkLJEOctolMaXId81TMtIcNxXGrdW
g0HNi4r17nUkNJWpHg3SYdC96kMYvCCBbxE1YG/CYKNThurMVyTonly67xPD
YOD2gB9PekgIrl8s376Ywe+HimYGDJGQENB9+qkPg4SFSO/ZJAnWirzPE4EM
Vvsb353D4oEXWU9pRDAYHZpbvVKbB0qDuw5+SmBwW8tgbZAhD0Kv847mHWLw
ZE1u7GoLHlwcrnF2/pPBzsrxPeY2PJAm5NrduMyg4pL6ri5nHqTKT+1SKf2Z
l7+bluTBg7mOa1KEyGBYtOLWFCkP9H2rSdsGBs1na+tuCuLBzA8SFcN25hef
eWDnEqTofs/gv5AurG0=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.011000000000000001`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.011000000000000001`], AbsoluteThickness[
       1.6]}, {}}}, {{}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
       LineBox[CompressedData["
1:eJwVx3k41HkcwPFJNK7BfCn7iCbGOHIMZn622q350Eoq1lGscbUpx5ZsjqZn
7BK1HY62jXJszo4topUzrfUxjkSOQlEoS5GxU1R2eUa2/eP9vJ634d5Iz/0K
NBrN9VP/e1aSrqJeIhcoCbXm3hSxcG/swYcZZXJBU2a7eulvLLQ3c8o2uC0X
VD8RPgq/ycKRtDkz7h25IGZ09YG/qljI9fXd5nlPLghrHX/a3cbCnjdrTmWN
yQWslPq3v8pYqG1QrMjRXxSEzr8KXdRfi1kiXNqUtigwaAu4+jZ0LW5JD799
JOmjoLZfg92obIh6wpXbI0OXBGccQ0zMcg1x50876B/YNIiJkc67WRnh0Ln2
e1W5NJh/nVoR1WaECrPtYm/NZbBhOtVn2zdsPHpSJVWcvAy6TJtj3d6xUaJZ
URG0XAGyw+ta25ONsUg23GkcowARHnGl53U52Etz3hohU4BIWq2f5BYHc8Js
yy/sWQ6HP/rNijaZINVy0i6hZzno9OTKVreZoOFuPTLtoghGXBZxDjTFyxu5
4+vvKkKO+65rvClTjPVK0lGxVwL/yun9lYlmuPpb8MspU4LBx+dOuK4yR5/m
hAw11groeqmc1lFgjuPCRQta9qe3PuUts1+HdGd5VZ8qHaYOZzAVm9ZhXMiG
PMuTdIilBya2Ci2wSTx6yWmJDv/EBfzQ+MYCC8dVz27+Xhks085y6sWW2J0Y
NVw3pQxHcpsuRjKtMD3Gj6UboAL8nQvdpnlWaOF/S8TvVAFd0W19tpk16ogc
rPu3qkL3tivVQ/XWmD6x68nuWlV46JGfn+/CxeCUayO+PDXYq7Q9kDPKRbpx
sHzNTTUwKnyvt7DRBh1IoXqzvjowyi7tCjlmgx08g7jpi+owsCLtcnWHDUqL
9YbeKzMgK+/Rj2rEFp+vOu7151EGbD5We1DRxxaNq83N1WYZENbcnTZWaItL
xR4znwdrAK1O60PLhC1a9NboTg5rwOO5BMVzPDv82z3f5qi7JjgwGAn+Yjs8
3jQTdB81QSTccvpBgx1W8Rvn3Ay0oOP09RaOGg+j7drtzb214OCEODPBg4eD
LrOclnQtGPOtaWjK5WHxs68LHHq0wLjKIK1kkodbP5NplykzYchoYOYXaz4m
HyqxH3JigjbDoz9YzMfsyBueC/FMKI0sX89r5CORDs3/W82E3RWD2ldWUMg7
xnW/844J8dHMPcs8KWShJD/cksD5Jh0nYRaFPWvZGGJFwERh4FBGNoVJicdf
BFsTmNxOz+7KoXDc8SvDQBsCdQ03ZI65FBa3tBR58gnIM+V5FkUU8jvarn7x
JYEw9U7txRIKXR53lTB2EpBuLHctaKBwwZ77QNWVwGv64ImnSOHNzJ+n6W4E
UhQP/KEjoVDD191KwZ2Am0en5ZlmCvuePSyb8yIgyzpDou5TGDjaV/7cj4DT
i96ZLb0UajpSj4b8CVz+PZMb30chFl2YHQwgMCZpjqjtp5C9z5vXF0Qg/bBQ
ajlA4eSrJ5VtwQS8fKKkK4cpzHFe39+yj0DkxXhL9xEKd1zP+iDZT0BU8C4i
+TmFZeG+9vWhBLoHdWc/jlIY1H7Huy6MQJC0lb9hjEItCz1RTTiBgNQRUfQ4
hZIUcWbldwSmSgPvlr6kMHr6aU35AQJsB+eliVcU/gegoUFN
        "]]},
      Annotation[#, "Charting`Private`Tag$29512#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{1.673312924295015, -22.997275742984183`},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameStyle->Automatic,
  FrameTicks->FrontEndValueCache[{{
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Log, Exp}]}, {
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Log, Exp}]}}, {{{{-23.025850929940457`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox],
          TraditionalForm], {0.01, 0.}}, {-20.72326583694641, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm], {0.01, 0.}}, {-18.420680743952367`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm], {0.01, 0.}}, {-16.11809565095832, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm], {0.01, 0.}}, {-13.815510557964274`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm], {0.01, 0.}}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm], {0.01, 0.}}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{"10", 
           RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
         TraditionalForm], {0.01, 0.}}, {-25.328436022934504`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-24.635288842374557`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-24.229823734266393`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.942141661814613`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.7189981105004, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.536676553706446`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.38252587387919, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.248994481254666`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.131211445598282`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-22.33270374938051, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.927238641272346`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.639556568820566`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.416413017506358`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.234091460712403`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.079940780885142`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-20.94640938826062, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-20.82862635260424, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-20.030118656386467`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-19.624653548278303`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-19.33697147582652, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-19.11382792451231, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18.931506367718356`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18.7773556878911, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18.643824295266576`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18.526041259610192`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-17.72753356339242, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-17.322068455284256`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-17.034386382832476`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.811242831518264`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.62892127472431, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.474770594897052`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.34123920227253, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.223456166616145`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-15.424948470398375`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-15.01948336229021, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.73180128983843, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.508657738524219`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.326336181730264`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.172185501903007`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.038654109278484`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-13.9208710736221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-13.122363377404328`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-12.716898269296165`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-12.429216196844383`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-12.206072645530174`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-12.02375108873622, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-11.86960040890896, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-11.736069016284437`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-11.618285980628055`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-10.819778284410283`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-10.41431317630212, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-10.126631103850338`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.903487552536127, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.721165995742174, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.567015315914915, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.433483923290392, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.315700887634009, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-8.517193191416238, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-8.111728083308073, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.824046010856292, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.600902459542082, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.418580902748128, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.264430222920869, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.1308988302963465`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.013115794639964, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-6.907755278982137, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-6.214608098422191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.809142990314028, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.521460917862246, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.298317366548036, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.115995809754082, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.961845129926823, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.8283137373023015`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}}, {{-23.025850929940457`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-20.72326583694641, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-18.420680743952367`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-16.11809565095832, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-13.815510557964274`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-11.512925464970229`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-9.210340371976182, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 
        0.}}, {-25.328436022934504`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-24.635288842374557`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-24.229823734266393`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.942141661814613`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.7189981105004, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.536676553706446`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.38252587387919, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.248994481254666`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-23.131211445598282`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-22.33270374938051, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.927238641272346`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.639556568820566`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.416413017506358`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.234091460712403`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-21.079940780885142`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-20.94640938826062, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-20.82862635260424, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-20.030118656386467`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-19.624653548278303`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-19.33697147582652, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-19.11382792451231, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18.931506367718356`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18.7773556878911, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18.643824295266576`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-18.526041259610192`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-17.72753356339242, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-17.322068455284256`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-17.034386382832476`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.811242831518264`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.62892127472431, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.474770594897052`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.34123920227253, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-16.223456166616145`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-15.424948470398375`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-15.01948336229021, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.73180128983843, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.508657738524219`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.326336181730264`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.172185501903007`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-14.038654109278484`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-13.9208710736221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-13.122363377404328`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-12.716898269296165`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-12.429216196844383`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-12.206072645530174`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-12.02375108873622, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-11.86960040890896, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-11.736069016284437`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-11.618285980628055`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-10.819778284410283`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-10.41431317630212, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-10.126631103850338`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.903487552536127, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.721165995742174, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.567015315914915, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.433483923290392, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-9.315700887634009, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-8.517193191416238, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-8.111728083308073, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.824046010856292, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.600902459542082, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.418580902748128, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.264430222920869, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.1308988302963465`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-7.013115794639964, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-6.907755278982137, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-6.214608098422191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.809142990314028, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.521460917862246, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.298317366548036, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-5.115995809754082, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.961845129926823, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}, {-4.8283137373023015`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
        0.}}}}, {{{2.302585092994046, 
        FormBox["10", TraditionalForm], {0.01, 0.}}, {2.995732273553991, 
        FormBox["20", TraditionalForm], {0.01, 0.}}, {3.912023005428146, 
        FormBox["50", TraditionalForm], {0.01, 0.}}, {4.605170185988092, 
        FormBox["100", TraditionalForm], {0.01, 0.}}, {0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.0986122886681098`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.3862943611198906`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.6094379124341003`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.791759469228055, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.9459101490553132`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.0794415416798357`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.1972245773362196`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.70805020110221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.4011973816621555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.6888794541139363`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.0943445622221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.248495242049359, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.382026634673881, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.499809670330265, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.0106352940962555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.298317366548036, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.703782474656201, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.991464547107982, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.214608098422191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}}, {{
       2.302585092994046, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       2.995732273553991, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       3.912023005428146, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       4.605170185988092, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}}, {
       0.6931471805599453, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.0986122886681098`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.3862943611198906`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.6094379124341003`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.791759469228055, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       1.9459101490553132`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.0794415416798357`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.1972245773362196`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       2.70805020110221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.4011973816621555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       3.6888794541139363`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.0943445622221, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.248495242049359, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.382026634673881, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       4.499809670330265, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.0106352940962555`, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.298317366548036, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.703782474656201, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       5.991464547107982, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}, {
       6.214608098422191, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}}}}}],
  
  GridLines->FrontEndValueCache[{
     Charting`ScaledTickValues[{Log, Exp}], 
     Charting`ScaledTickValues[{Log, Exp}]}, {{{2.302585092994046, 
       Directive[]}, {2.995732273553991, 
       Directive[]}, {3.912023005428146, 
       Directive[]}, {4.605170185988092, 
       Directive[]}}, {{-23.025850929940457`, 
       Directive[]}, {-20.72326583694641, 
       Directive[]}, {-18.420680743952367`, 
       Directive[]}, {-16.11809565095832, 
       Directive[]}, {-13.815510557964274`, 
       Directive[]}, {-11.512925464970229`, 
       Directive[]}, {-9.210340371976182, 
       Directive[]}}}],
  GridLinesStyle->Directive[
    GrayLevel[0.4, 0.5], 
    AbsoluteThickness[1], 
    AbsoluteDashing[{1, 2}]],
  ImageSize->{978.03515625, Automatic},
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Exp[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Exp[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& )}},
  PlotRange->{{1.673312924295015, 
   4.605170185988092}, {-22.997275742984183`, -7.90556522469544}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{
    Charting`ScaledTicks[{Log, Exp}], 
    Charting`ScaledTicks[{Log, Exp}]}]], "Output",
 CellChangeTimes->{3.799477126476359*^9, 3.7994772435257683`*^9, 
  3.799477639458869*^9, 3.799477701776313*^9, 3.79947776322362*^9, 
  3.799477891794919*^9, 3.799477927059317*^9, 3.7994779952620087`*^9, 
  3.799478063546814*^9, 3.7994797256686296`*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"75ad85bc-03d6-4954-9c11-8c419256d07a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute a quick inspiral using the (2,2)-flux", "Subsection",
 CellChangeTimes->{{3.799478048812603*^9, 
  3.799478058353503*^9}},ExpressionUUID->"d106a704-b217-4377-8d0b-\
8a6e13da87df"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flux", "=", 
  RowBox[{"Interpolation", "[", "fluxData", "]"}]}]], "Input",
 CellChangeTimes->{{3.799476547020774*^9, 3.799476553026691*^9}, {
  3.799476639205639*^9, 3.799476653185597*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"9f512d06-942d-4d51-9eab-6a2837ffdca2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["InterpolatingFunction",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquarePlusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAAUqiEsDh5MkDiSEWTDBy2Pgrxp5Xc
wjJA37JVEb0atD4ZgM2zAko0QPlllSi1Wqs+PnJWCCjyNUDqwzbNeZeiPlEX
/5QefjdAWx3aHkqXmj5f/90DSwI5QCK242Lli5M+hEogqXanOkBogOWKg5CM
PpZIgoZzMDxA9+8utCOuhT6/qUeab9o9QD5WoGnzV4A+401DkKF8P0BsXopi
fyN5PnlSL19SgUBASunfkF3qcz6Nr26R01RBQAgaJ5bXTW8+F+a9Xz0aQkBR
jyx/M0FpPi3OPskm8EJAHaZRbKQ2ZD7A19ojK8JDQGXDfJNOZWA+yrqGGhiG
RECcECPbjC5bPl9PZKyEWkVA4KkMpnRZVj5rvVHa2SBGQK9YpOjfvVI+9Uxa
+UnjRkBgs0yj77lPPgqOlLM5tkdA1gs2Ll6jSj6WqN4JEntIQPpmRBgcwEY+
rXRa+2lQSUAr2kWln0dDPkJi8d3cIUpAWmbggyd5QD5NKZhcOOVKQGQH3/Tx
kjw+5KFwdhO5S0CpeomxWpg4PvHzWCzXfkxA8h0wmKp3NT58Z1zTtUBNQCEA
7+iL2jI+koyRFRQTTkCUPVwF+m8wPh+L1vNa105A4BbdZqgFLT43O01tIaxP
QLqyzpPicCk+Y+JpQWg5UEB67Bze75AmPum3ukTNmlBAVPnmg0YeJD40ZqQV
cgRRQPLZ7TRy0CE+OwGWNAtnUUDh2sQ8bOMfPgd1ICHk0VFASOBKuLRaHD6S
eTiGyjpSQEPrT/skVRk+2GpYOaWcUkCNZiuFH9sWPuQ0Ebq/BlNAYmWaItJ9
FD6s69GIzmlTQDlSUvFsixI+MjMg0OrKU0C5Wa2u99gQPn5TB+VGNFRAWMJ0
SN5sDj6FYPZHl5ZUQHXydm9Ltgs+UkZ+eCcBVUCbdLEYpxcJPt68kyHFaVVA
fcBh1PTNBj4lILEYV8tVQJPsw1eb5AQ+Mlxn3Sg1VkAQDUwEbggDPvqEJfDu
l1ZA5i2P8jF5AT6IhnzQ9AJXQGzmCxEr6P891RhhKQhsV0C75gNn2Tn9Pd2X
TdAPzldA5nD/mhf3+j2r79JEVzhYQIPjjFw4v/g9NDRgB5ObWEDhHgeU7972
Pe5KUfn//1hAls7/H60k9T1l0XwE
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$30797#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{6., 100.}, {0., 1.3178328802277525`*^-6}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"6.`", ",", "100.`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEBitmaps", "SquareMinusIconMedium"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 3.5 CurrentValue["FontCapHeight"]/
                AbsoluteCurrentValue[Magnification]}]], 
            GraphicsBox[{{{{}, {}, 
                TagBox[{
                  Directive[
                   Opacity[1.], 
                   RGBColor[0.368417, 0.506779, 0.709798], 
                   AbsoluteThickness[1]], 
                  LineBox[CompressedData["
1:eJwBYQOe/CFib1JlAgAAADUAAAACAAAAUqiEsDh5MkDiSEWTDBy2Pgrxp5Xc
wjJA37JVEb0atD4ZgM2zAko0QPlllSi1Wqs+PnJWCCjyNUDqwzbNeZeiPlEX
/5QefjdAWx3aHkqXmj5f/90DSwI5QCK242Lli5M+hEogqXanOkBogOWKg5CM
PpZIgoZzMDxA9+8utCOuhT6/qUeab9o9QD5WoGnzV4A+401DkKF8P0BsXopi
fyN5PnlSL19SgUBASunfkF3qcz6Nr26R01RBQAgaJ5bXTW8+F+a9Xz0aQkBR
jyx/M0FpPi3OPskm8EJAHaZRbKQ2ZD7A19ojK8JDQGXDfJNOZWA+yrqGGhiG
RECcECPbjC5bPl9PZKyEWkVA4KkMpnRZVj5rvVHa2SBGQK9YpOjfvVI+9Uxa
+UnjRkBgs0yj77lPPgqOlLM5tkdA1gs2Ll6jSj6WqN4JEntIQPpmRBgcwEY+
rXRa+2lQSUAr2kWln0dDPkJi8d3cIUpAWmbggyd5QD5NKZhcOOVKQGQH3/Tx
kjw+5KFwdhO5S0CpeomxWpg4PvHzWCzXfkxA8h0wmKp3NT58Z1zTtUBNQCEA
7+iL2jI+koyRFRQTTkCUPVwF+m8wPh+L1vNa105A4BbdZqgFLT43O01tIaxP
QLqyzpPicCk+Y+JpQWg5UEB67Bze75AmPum3ukTNmlBAVPnmg0YeJD40ZqQV
cgRRQPLZ7TRy0CE+OwGWNAtnUUDh2sQ8bOMfPgd1ICHk0VFASOBKuLRaHD6S
eTiGyjpSQEPrT/skVRk+2GpYOaWcUkCNZiuFH9sWPuQ0Ebq/BlNAYmWaItJ9
FD6s69GIzmlTQDlSUvFsixI+MjMg0OrKU0C5Wa2u99gQPn5TB+VGNFRAWMJ0
SN5sDj6FYPZHl5ZUQHXydm9Ltgs+UkZ+eCcBVUCbdLEYpxcJPt68kyHFaVVA
fcBh1PTNBj4lILEYV8tVQJPsw1eb5AQ+Mlxn3Sg1VkAQDUwEbggDPvqEJfDu
l1ZA5i2P8jF5AT6IhnzQ9AJXQGzmCxEr6P891RhhKQhsV0C75gNn2Tn9Pd2X
TdAPzldA5nD/mhf3+j2r79JEVzhYQIPjjFw4v/g9NDRgB5ObWEDhHgeU7972
Pe5KUfn//1hAls7/H60k9T1l0XwE
                   "]]}, 
                 Annotation[#, "Charting`Private`Tag$30797#1"]& ]}}, {}}, {
             DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
              AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
              GridLines -> {None, None}, DisplayFunction -> Identity, 
              PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
              All, DisplayFunction -> Identity, AspectRatio -> 1, 
              Axes -> {False, False}, AxesLabel -> {None, None}, 
              AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
              Frame -> {{True, True}, {True, True}}, 
              FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                RGBColor[0.368417, 0.506779, 0.709798]], 
              FrameTicks -> {{None, None}, {None, None}}, 
              GridLines -> {None, None}, GridLinesStyle -> Directive[
                GrayLevel[0.5, 0.4]], ImageSize -> 
              Dynamic[{
                Automatic, 3.5 CurrentValue["FontCapHeight"]/
                 AbsoluteCurrentValue[Magnification]}], 
              Method -> {
               "DefaultBoundaryStyle" -> Automatic, 
                "DefaultGraphicsInteraction" -> {
                 "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                  "Effects" -> {
                   "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                "DefaultMeshStyle" -> AbsolutePointSize[6], 
                "ScalingFunctions" -> None, 
                "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
              PlotRange -> {{6., 100.}, {0., 1.3178328802277525`*^-6}}, 
              PlotRangeClipping -> True, PlotRangePadding -> {{
                 Scaled[0.1], 
                 Scaled[0.1]}, {
                 Scaled[0.1], 
                 Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"6.`", ",", "100.`"}], "}"}], "}"}], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"scalar\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["3", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Hermite\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["False", "SummaryItem"]}]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  InterpolatingFunction[{{6., 100.}}, {
   5, 7, 0, {95}, {4}, 0, 0, 0, 0, Automatic, {}, {}, False}, CompressedData["

1:eJw1ydkqhXEUxuGXq3DgAEmSxDbPH7Z53uYjpRy7hXVp/0ujvseq1dOvd/rr
Z/Q9nmTs7z/zfxNd7ySnOMNZznGeC1zkEpe5wgFXucZ1bnCTW9zmDne5x30e
8JBdbzFHmjnWzIlmhpo51cyZZs41c6GZS81caeZaMzeaudXMnWbuNfPQ27HY
mEc7i40Z2VlszJOdxcY821lszIudxca82llszJudxca821lszEf3C39nSUk=

   "], {Developer`PackedArrayForm, {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 
    13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 
    31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 
    49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 
    67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 
    85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95}, CompressedData["
1:eJwBBQP6/CFib1JlAQAAAF8AAACAi/9Phik4P48U79IWbyU/xDscu82dFT+A
UeS6udkHPwAMa3ZiJ/w+fm9dtoCF8T5p/VUS5cPmPrCPBBn+pd4+j3Gt7ilC
1T5+s78+wkHOPv5M0KIMBMY+x3lzCHlVwD4IBUZH+Ke4PtsYBfZK5bI+jEPx
hWpcrT7K9T2NDhinPudsQE5YXqI+pvZSi6+EnT4puEQkffCXPuSL0QK+lJM+
reh9gXYkkD5TGPzNJs+KPrUjsGOYaYY+YpOg9rfagj7GF7UxV+h/PsZity6I
JXs+Lku8nsM2dz7rtnjwPfJzPiKb3ARDN3E+fH1Kwz7YbT5Siap69/hpPguT
YqM5sGY+wvWg1gDkYz6TSOneRX9hPh1ofcgC4l4+ucWwco5WWz5wIlkhXkVY
Ph07KpKdm1U+OAWg78RJUz7kbh7S2kJRPt3jkXcj+E4+WOXxAq/YSz56dq/Y
HRhJPoq5D6SEqUY+ihIuMwKCRD6+wqSdQ5hCPhK9fNxc5EA+cSS2eAq/Pj73
VQDY0Qc8PsWLKZoLmTk+2HhauQ1qNz4DiMiMWHM1PoU/EpBsrjM+wjMIWp0V
Mj548aTo/aMwPvSFIBN4qi4+E/h7jiRLLD4dI1eGVyMqPoVRmcpCLSg+zl2R
bLtjJj6LsvW+OcIkPsYe1O2xRCM+AdaR/pPnIT6R6U9LtacgPqIKO4GKBB8+
TpUG9HjpHD5aZFTGxPkaPtJGMiRiMRk+5ay30LWMFz6Y5LfjiQgWPnZWdIcC
ohQ+7P4AdIdWEz6p56hqrSMSPl1fiF1bBxE+cv72VGP/Dz6+VI/s5BUOPouu
XJ0XTww++U8CUyaoCj4NEfaGfx4JPl6aMv7Jrwc+FmU3yeRZBj440xzD4hoF
PpaEWs768AM+/g2LV5XaAj6ZctDQNdYBPjvnIfSF4gA+tk4kAIz8/z3AcDr0
r1D+PTF93dZfv/w9XZlzxblG+z30WOri9uT5PaBEUtyBmPg9Z1NDZOBf9z3w
AvGxrjn2PbEO7gOtJPU94L1gww==
    "]}, {Automatic}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{{3.799476549898769*^9, 3.799476553863246*^9}, 
   3.799476654247292*^9, 3.799479726222499*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"fc6ac8bd-99f2-4a34-9522-52ff7ffd1a17"]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["r0", "."], "=", 
    RowBox[{
     FractionBox["dr", "dE"], 
     FractionBox["dE", "dt"]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "44c2a1ef-2b80-4949-ab77-6d17a5b598e4"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["dE", "dt"], "=", 
    RowBox[{"-", 
     OverscriptBox["\[ScriptCapitalE]", "."]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "8fc90d38-c148-49e4-ae5c-f26e3b7a459c"]
}], "Text",
 CellChangeTimes->{{3.7994766637374487`*^9, 3.799476680084371*^9}, {
  3.799476968514721*^9, 
  3.799476981473921*^9}},ExpressionUUID->"b26d7909-87c0-4dde-aaa0-\
5f5274a3c52a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"drdE", "=", 
   SuperscriptBox[
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"KerrGeoEnergy", "[", 
       RowBox[{"0", ",", "r1", ",", "0", ",", "1"}], "]"}], ",", "r1"}], 
     "]"}], 
    RowBox[{"-", "1"}]]}], ";"}]], "Input",
 CellChangeTimes->{{3.799476845585939*^9, 3.799476886871331*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"44185acc-087c-4772-a928-35c68f9f13ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"r0dotEq", "[", 
    RowBox[{"r1_", "?", "NumericQ"}], "]"}], "=", 
   RowBox[{
    RowBox[{"-", "drdE"}], " ", 
    RowBox[{"Flux", "[", "r1", "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7994766816610003`*^9, 3.79947677023349*^9}, {
   3.79947683135382*^9, 3.7994768575763597`*^9}, {3.799476888290984*^9, 
   3.799476892934998*^9}, 3.799476964453463*^9},
 CellLabel->"In[36]:=",ExpressionUUID->"c9471b16-9303-4035-bd63-2fe4944d4451"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", 
  RowBox[{
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"r1", "'"}], "[", "t", "]"}], "\[Equal]", 
        RowBox[{"r0dotEq", "[", 
         RowBox[{"r1", "[", "t", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"r1", "[", "0", "]"}], "\[Equal]", "100"}]}], "}"}], ",", 
     RowBox[{"{", "r1", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", 
       SuperscriptBox["10", "10"]}], "}"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7994767710779057`*^9, 3.799476821587549*^9}, {
  3.799476868209811*^9, 3.799476869894841*^9}, {3.799476908204234*^9, 
  3.799476927349612*^9}, {3.799476987753234*^9, 3.799477019522896*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"9062313f-5798-41f9-b942-4352abd08ad8"],

Cell[BoxData[
 TemplateBox[{
  "NDSolve", "ndsz", 
   "\"At \\!\\(\\*RowBox[{\\\"t\\\"}]\\) == \
\\!\\(\\*RowBox[{\\\"4.01336431105909`*^6\\\"}]\\), step size is effectively \
zero; singularity or stiff system suspected.\"", 2, 37, 1, 
   17467483838358097346, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.799477019851653*^9, 3.799479726317134*^9},
 CellLabel->
  "During evaluation of \
In[37]:=",ExpressionUUID->"18d8e0ca-dac2-48a5-9cb1-675822290d3a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"r1", "\[Rule]", 
   InterpretationBox[
    RowBox[{
     TagBox["InterpolatingFunction",
      "SummaryHead"], "[", 
     DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = 
      "Ready"}, 
      TemplateBox[{
        PaneSelectorBox[{False -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquarePlusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = True), Appearance -> None,
                 Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, 
                  TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAKJKXpPZpsT/3Nzf+//9YQAn25xIe
8u9A0YAU86blWEAjsbz7B6UAQeeG6Fa3yFhArAqtMKa6CEHoAOhsVq1YQJ9Q
t7HVUxBBKJqK5CWSWECJUeQJVaAUQapGk3tAdFhAaCUIQWOjGEEYb28c9ldY
QOgu+DZu/BxBIuXwAt04WEB2a+hVlqAgQavUmIDfGVhA8ijQ/zyeIkFETNp2
ivxXQD8BHgnixiRBTbo+LUHcV0AGQ+eBzsomQUkyvqSlvVdAD9QkupTEKEHU
LgBIMJ9XQOh/yFFZ6SpBHg1DYJ19V0A8ledYZeksQRK1cXjGXVdAYMVsv28U
L0GsmKFvrjpXQGMis/KpmjBBRSNoIJ4XV0DTlm29v5gxQTKLDCNZ9lZArBjb
t1SsMkFFEuQIntFWQEJPBmqNrTNBVsnLYrOuVkBAk+RLRcQ0QYSpTSUliFZA
3/58DerVNUF016pXh2FWQDsf04Yy1TZBnDV1Fco8VkD/TNwv+uk3QZ4tvwkk
FFZAgS+jkGXsOEHhe9Z6Yu1VQKQ5JNG96TlBaUrOXJnGVUAvUVhBlfw6Qe1I
GFyXm1VAdx1KaRD9O0Hg7bhiiXJVQCf37sAKEz1BAq2eTftEVUB4+E348SM+
QU42ztofF1VAhq5q53wiP0HPbUCIR+tUQP44HYNDG0BB0cf+HX26VEAY9WNu
GpxAQRd+ViG0i1RAAsWHyWcaQUFotE49mlxUQKEbhbx0o0FBtE8poAMoVECe
TGGLUyNCQf9uPs529VNATwQX8vGtQkG2MMXA7LxTQF+WqzRiL0NBtXQyuV6G
U0A/PB3nSK5DQbpkomgaT1NA02hoMe83REGfBqiG/hBTQMZvkldnuERBrJEI
T9LUUkBt/ZUVn0NFQSrkbOT6kFJA5Z52Q03MRUFkseHocEtSQLsaNk3NS0ZB
zG9TfawHUkBFHc/uDNZGQQmU1cSsulFALvpGbB5XR0Esoyj2F29RQOfqm1mm
1UdBKgYSvBghUUBVYsre7V5IQYpIbpyCx1BAIbTXPwffSEF76PLekW5QQKGM
vjjgaUlBzjeri14HUEDyeIKhL/JJQTj/34DTM09AoT8l5lBxSkG4pmvIJlZO
QAWNocIx+0pBOBt6oDlOTUDHtPx65HtLQdfiqDsNPExAPWMxy1YHTEHxEQON
A+tKQIQlQ4s/kExByQf6y+hnSUApwjMn+g9NQXn6xZqes0dAguX9WnSaTUG0
NFcfBE9FQDrjpmrAG05BSmYKJ9L2QUBzzRsfmp5OQb1Umj97WRhAVwGr9A==

                    "]]}, 
                   Annotation[#, "Charting`Private`Tag$30903#1"]& ]}}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 4.01336431105909*^6}, {0., 
                 99.99999957458918}}, PlotRangeClipping -> True, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "4.01336431105909`*^6"}], "}"}], 
                    "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}], True -> GridBox[{{
              PaneBox[
               ButtonBox[
                DynamicBox[
                 FEPrivate`FrontEndResource[
                 "FEBitmaps", "SquareMinusIconMedium"]], 
                ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                None, Evaluator -> Automatic, Method -> "Preemptive"], 
               Alignment -> {Center, Center}, ImageSize -> 
               Dynamic[{
                 Automatic, 3.5 CurrentValue["FontCapHeight"]/
                  AbsoluteCurrentValue[Magnification]}]], 
              GraphicsBox[{{{{}, {}, 
                  TagBox[{
                    Directive[
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1]], 
                    LineBox[CompressedData["
1:eJwB0QMu/CFib1JlAgAAADwAAAACAAAAKJKXpPZpsT/3Nzf+//9YQAn25xIe
8u9A0YAU86blWEAjsbz7B6UAQeeG6Fa3yFhArAqtMKa6CEHoAOhsVq1YQJ9Q
t7HVUxBBKJqK5CWSWECJUeQJVaAUQapGk3tAdFhAaCUIQWOjGEEYb28c9ldY
QOgu+DZu/BxBIuXwAt04WEB2a+hVlqAgQavUmIDfGVhA8ijQ/zyeIkFETNp2
ivxXQD8BHgnixiRBTbo+LUHcV0AGQ+eBzsomQUkyvqSlvVdAD9QkupTEKEHU
LgBIMJ9XQOh/yFFZ6SpBHg1DYJ19V0A8ledYZeksQRK1cXjGXVdAYMVsv28U
L0GsmKFvrjpXQGMis/KpmjBBRSNoIJ4XV0DTlm29v5gxQTKLDCNZ9lZArBjb
t1SsMkFFEuQIntFWQEJPBmqNrTNBVsnLYrOuVkBAk+RLRcQ0QYSpTSUliFZA
3/58DerVNUF016pXh2FWQDsf04Yy1TZBnDV1Fco8VkD/TNwv+uk3QZ4tvwkk
FFZAgS+jkGXsOEHhe9Z6Yu1VQKQ5JNG96TlBaUrOXJnGVUAvUVhBlfw6Qe1I
GFyXm1VAdx1KaRD9O0Hg7bhiiXJVQCf37sAKEz1BAq2eTftEVUB4+E348SM+
QU42ztofF1VAhq5q53wiP0HPbUCIR+tUQP44HYNDG0BB0cf+HX26VEAY9WNu
GpxAQRd+ViG0i1RAAsWHyWcaQUFotE49mlxUQKEbhbx0o0FBtE8poAMoVECe
TGGLUyNCQf9uPs529VNATwQX8vGtQkG2MMXA7LxTQF+WqzRiL0NBtXQyuV6G
U0A/PB3nSK5DQbpkomgaT1NA02hoMe83REGfBqiG/hBTQMZvkldnuERBrJEI
T9LUUkBt/ZUVn0NFQSrkbOT6kFJA5Z52Q03MRUFkseHocEtSQLsaNk3NS0ZB
zG9TfawHUkBFHc/uDNZGQQmU1cSsulFALvpGbB5XR0Esoyj2F29RQOfqm1mm
1UdBKgYSvBghUUBVYsre7V5IQYpIbpyCx1BAIbTXPwffSEF76PLekW5QQKGM
vjjgaUlBzjeri14HUEDyeIKhL/JJQTj/34DTM09AoT8l5lBxSkG4pmvIJlZO
QAWNocIx+0pBOBt6oDlOTUDHtPx65HtLQdfiqDsNPExAPWMxy1YHTEHxEQON
A+tKQIQlQ4s/kExByQf6y+hnSUApwjMn+g9NQXn6xZqes0dAguX9WnSaTUG0
NFcfBE9FQDrjpmrAG05BSmYKJ9L2QUBzzRsfmp5OQb1Umj97WRhAVwGr9A==

                    "]]}, 
                   Annotation[#, "Charting`Private`Tag$30903#1"]& ]}}, {}}, {
               DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
                AxesOrigin -> {0, 0}, FrameTicks -> {{{}, {}}, {{}, {}}}, 
                GridLines -> {None, None}, DisplayFunction -> Identity, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, PlotRangeClipping -> True, ImagePadding -> 
                All, DisplayFunction -> Identity, AspectRatio -> 1, 
                Axes -> {False, False}, AxesLabel -> {None, None}, 
                AxesOrigin -> {0, 0}, DisplayFunction :> Identity, 
                Frame -> {{True, True}, {True, True}}, 
                FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                Directive[
                  Opacity[0.5], 
                  Thickness[Tiny], 
                  RGBColor[0.368417, 0.506779, 0.709798]], 
                FrameTicks -> {{None, None}, {None, None}}, 
                GridLines -> {None, None}, GridLinesStyle -> Directive[
                  GrayLevel[0.5, 0.4]], ImageSize -> 
                Dynamic[{
                  Automatic, 3.5 CurrentValue["FontCapHeight"]/
                   AbsoluteCurrentValue[Magnification]}], 
                Method -> {
                 "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultMeshStyle" -> AbsolutePointSize[6], 
                  "ScalingFunctions" -> None, 
                  "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& ), "CopiedValueFunction" -> ({
                    (Identity[#]& )[
                    Part[#, 1]], 
                    (Identity[#]& )[
                    Part[#, 2]]}& )}}, 
                PlotRange -> {{0., 4.01336431105909*^6}, {0., 
                 99.99999957458918}}, PlotRangeClipping -> True, 
                PlotRangePadding -> {{
                   Scaled[0.1], 
                   Scaled[0.1]}, {
                   Scaled[0.1], 
                   Scaled[0.1]}}, Ticks -> {Automatic, Automatic}}], 
              GridBox[{{
                 RowBox[{
                   TagBox["\"Domain: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"0.`", ",", "4.01336431105909`*^6"}], "}"}], 
                    "}"}], "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Output: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"scalar\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Order: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["3", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Method: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["\"Hermite\"", "SummaryItem"]}]}, {
                 RowBox[{
                   TagBox["\"Periodic: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox["False", "SummaryItem"]}]}}, 
               GridBoxAlignment -> {
                "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
               False, GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
               BaseStyle -> {
                ShowStringCharacters -> False, NumberMarks -> False, 
                 PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
            GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
            GridBoxItemSize -> {
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
            BaselinePosition -> {1, 1}]}, 
         Dynamic[Typeset`open$$], ImageSize -> Automatic]},
       "SummaryPanel"],
      DynamicModuleValues:>{}], "]"}],
    InterpolatingFunction[{{0., 4.01336431105909*^6}}, {
     5, 7, 1, {835}, {4}, 0, 0, 0, 0, Automatic, {}, {}, 
      False}, CompressedData["
1:eJw91gc41d//AHArIhIys1ckMspeBxlxPxJFGRkpiiQqRCnZeyslGkLpG5Ui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     "], {Developer`PackedArrayForm, CompressedData["
1:eJwl1mFEIAASBtBur0uSJEmSdEmSJEmSJEmSJEmSJEmSdEmSJEmSJEmSJEmS
JEmSJEmSJFkrSZIkSZIkSXJv74b3f5gZ3/y74T8Vbf8ICAgo/GfA/+oXgQQR
TAihhBFOBJFEEU0MscQRTwKJJJFMCqmkkU4GmWSRTQ655JFPwd9eKKKYEkop
o5wKKqmimhpqqaOeBhppopkWWmmjnQ466aKbHnrpo58BBhlimBFGGWOcCSaZ
YpoZZpljngUWWWKZFVZZY50NNtlimx122WOfAw454pgTTjnjnN/84YJLrrjm
hlvuuOeBR5545oVX3njng0+++OaHAIvwi0CCCCaEUMIIJ4JIoogmhljiiCeB
RJJIJoVU0kgng0yyyCaHXPLIp4BCiiimhFLKKKeCSqqopoZa6qingUaaaKaF
Vv4ueTsddNJFNz300kc/AwwyxDAjjDLGOBNMMsU0M8wyxzwLLLLEMiusssY6
G2yyxTY77LLHPgcccsQxJ5xyxjm/+cMFl1xxzQ233HHPA4888cwLr7zxzgef
fPHND3+P/xeBBBFMCKGEEU4EkUQRTQyxxBFPAokkkUwKqaSRTgaZZJFNDrnk
kU8BhRRRTAmllFFOBZVUUU0NtdRRTwONNNFMC6200U4HnXTRTQ+99NHPAIMM
McwIo4wxzgSTTDHNDLPMMc8CiyyxzAqrrLHOBptssc0Ou+yxzwGHHHHMCaec
cc5v/nDBJVdcc8Mtd9zzwCNPPPPCK2+888EnX3zzQ4AM+EUgQQQTQihhhBNB
JFFEE0MsccSTQCJJJJNCKmmkk0EmWWSTQy555FPwz/9nURHFlFBKGeVUUEkV
1dRQSx31NNBIE8200Eob7XTQSRfd9NBLH/0MMMgQw4wwyhjjTDDJFNPMMMsc
8yywyBLLrLDKGutssMkW2+ywyx77HHDIEceccMoZ5/zmDxdccsU1N9xyxz0P
PPLEMy+88sY7H3zyxTc//A3+XwQSRDAhhBJGOBFEEkU0McQSRzwJJJJEMimk
kkY6GWSSRTY55JJHPgUUUkQxJZRSRjkVVFJFNTXUUkc9DTTSRDMttNJGOx10
0kU3PfTSRz8DDDLEMCOMMsY4E0wyxTQzzDLHPAssssQyK6yyxjobbLLFNjvs
ssc+BxxyxDEnnHLGOb/5wwWXXHHNDbfccc8DjzzxzAuvvPHOB5988c0PAf8y
fwIJIpgQQgkjnAgiiSKaGGKJI54EEkkimRRSSSOdDDLJIpsccskjnwIKKaKY
Ekopo5wKKqmimhpqqaOeBhppopkWWmmjnQ466aKbHnrpo58BBhlimBFGGWOc
CSaZYpoZZpljngUWWWKZFVZZY50NNtlimx122WOfAw454pgTTjnjnN/84YJL
rrjmhlvuuOeBR5545oVX3njng0+++OaHv0//LwIJIpgQQgkjnAgiiSKaGGKJ
I54EEkkimRRSSSOdDDLJIpsccskjnwIKKaKYEkopo5wKKqmimhpqqaOeBhpp
opkWWmmjnQ466aKbHnrpo58BBhnivxeHme4=
      "], CompressedData["
1:eJwt1nc01+/7B3AhGlSkvO29995c9t5bQkgUGSkSpWxKSbQl9IlEoY339ZZK
ZqVIKjJCVJI9+93fc36v/x7nvl7P+7ru8zrndQv5hzvtXUdHR5fKRPf/jydM
hE0v7dTppXJax1Wf/ucBLVPhmxN1e6lGjA0+XMRZ4eMWP/R6qcFu3+8or3nA
omCWRh30UtPsVfusVz3A4U5671njXupk3e2FwBUPELRQUQ4066XKnMESr2kP
oNis1nT791Ir+jckmo17wHqB04I5J3qpbZGPIyUHPED+QW31hWu91L3uMX50
PR7wcFN42eDTXuo38efsUcUe4L+ubNVv72cqvU8ong4j9Rn59IY8X6ievZmg
o+4BEYV/LqV9+UL1rjF0CVp1B8xpkAy885WqWe1gPPPcHYIedO2QSe2jlu17
tE/vmDs0VJsunr/RT1300h/9pugOwT9vCf4M/kb1vZhvdHPIDdTT0tdstg1Q
n67lv9fIdQNbFjwr8HqAKn3gzx0nAzdY9H6itTN3kHplgxjD+VFXaOO97JkU
PUT9InD9TmeBK2QFBy67ag9TyyTDhXmcXeGTBduvtO3fqepF25r5GV3hiH3P
OyOGEarzxg/syVUu8K5/YfAA6yhV5kjDDF2YC1irqCxsmR+lKnL+sX0g5gJm
ig/0T8yPUVumjke5fXYGX8/Snkj2cWoB9evN3DPOsLS3TT3JZoL67MSEyEZd
Z4jd/VbQr/wn9fePPewPVpyg7pPOKZ22X9Qy8S8+b545gX4f9wXZjZPUFyam
QVxHnCC4jsq4S+UPdUqqotFU3gmYz6e8VJj9Q73HH6P87q8jBNzU3PqtYIqa
+bwgfvGBI1w7IZI+5vGXevRqzeZT0Y4w1s6QNS42TT2WfNdEVMkR9EZ/0bg3
zlAnqH6ObxcdIFkxMsatY4ZK/6ybz5bmAK7Nk4f1/5ulzp5J1Q1MdoDJLp9x
Wu4c9Wj7cnC3qQPs4yyOOnplnqp84GiEJ6MDXEtb1ftBXaAaJsjbqF+0h38l
ekEvWxepc3fodr4QtAetIR2f0ZklKtXBPL6zxA6epem4GBqsUOvHLZ4FgB3I
xacLX/VapboarFv+8dEWGIfsmN1y1qgXgj+4re23BWfdYe6Po/+oUnQpPZKL
NmCXJrHtVRUdely+tufLSRvoZubZcDVlHTJ8WKReErYBiqJa2B9NemxzKhzY
j9bwqWn6ytIqPW46tPnbT3dryD4QyV/8kQE/mrin356wguanDbtTmhlxylMi
4OdZK7gUY7D3VtF65D9n1+muaAX/DB0XSnKYsHc+wpanzxKm4567HtrPjF3R
gTwP0i2hYZ3MiqX7Bux+cNSrS8ESKqq2tErv2oiUh8/+e/LdAtYXnGbhM9iE
v0MLD0xdsoBTlJOGleqb8USUSbSxpQXou6sNlpmwYMD2sPMhc+ZQ3N24mBjK
ityyxd+2F5qDzJPk89LVW/BDqh1X725zOP+L36r/yVa89ibP3ZvLHH5uT9c4
vX8bnmSQ2LS/0wweyzfv6mJkQ9WKusHWdDPwTV/l31nBhkwiZT5GumZglfXy
u9Vedoxb5kkSI77hbKt7nnjzd/7bG4jXKXde/ET89HNVy4SOGXz0GZoVDGLH
lM8ffnUQc64lugUTh39L21ZNrKZa/vQeseo4q2ss8Y0f51L197Fj99D7i/rE
XIfv7G4ndqr41MNInLKyoO8dzI7PjCrpGzXNoP5VgP50GDv6ZH2PT1Q3A75s
P4PsQ+z4moveXE/VDJorfMzkjrKj7cEUv0UlM9gX3un+9jg7rtyNpJPlMQMB
phYRtifsWPpzNpqT0Qwua5jlLv5lx+zvTVVPf5rC1sjMvGyF7TjjM35lW5cp
BJjeU/oTth2X2yp+cNWbQrgCl59m5XbMY7Eo3nnJFChjbR/rt3PgvIFiu2OU
KWi5/z0jfZwDEyzV5xqsTaGxgvVUzy8O1G0qHPQWNYUWC/VLNgE7MKvl3W7O
FRNQfHNffaVvB2ZfX918qc0EeIwCfl86vBOZ09v4L5eagO64d1HYxE68wNBY
0ptkAuUm3au8+zixyy+dw9nHBNrzOjJnxjjxwe4eRaq+CWhrp5sreFIwq0xU
JpffBAwSrSv2dlBwU3WyeeuqMQy4BDH/suDCMGpskO8XYxiK7Ylbe82F0nuO
TJs/M4Y7G5fG1ey58ap8e2r8RWNoaCmo3PKFGz//YZSeOWQMV3OXU+fDeXCJ
2mp7y94YhPPjdSM382J7z0TQkKwxxB04Y/uwhBfjjOsf+W00hqfZoka/TfnQ
++iS8vbvRrDUr6CdOcmHWeuD7314ZQTen5lyWhP5sZznVdy6UiNoXZf7oo4i
gPqHCm6dTzeCLVfSdHsfC2DUJcuuxGAj8GpO2KilIIhXJPj1X5gbwS43oyc3
UwVRLWivvou4ERhqMztlDApixWfzGAlGI+D4MOJiayyENQXBEyoDhpDT13ZE
okwI47gaHdxfGULloNabK4tCWBdo8G7tjiE0eFD3pNsKY8FiB4PYWUMoBs0X
sreEcYGJRfZFlCEw3klfu08ngtE7Y0y6XQ3B54eGxC4/Ebxb973eRdMQQu56
frzyQgRjXzMEanIbAjWrc6FFThRxy6eko8sAXJJhnYbXRPG30Ii3XDvAfrFf
OSEWYnhBqfECP/HwwouGm8Tc2kfbthIn/L0y/Yk4S3sD4zriDWbvxNktxfCv
UoTO3zaAVbrgXVbEuwSqooaIVZV8c04RPx0a/vaSuLeql26a2Csm3q6U+NfF
nsMBVmJ4qTOmNpM4wcnzz3viR13Vn/1bAfKGPo1p2YthaP0rqnYLAKOL7aYi
ZzEsvp4XyN4McPO2nxuLhxh2Oq1r/9EE4On+vCPWWwx3uFHzzeoAQlm44+Uz
xHBJ/MJA5n2ANReVjhePxPD54+dKj0oAkh2L842+i+GTW53Mry8BHGFt7qjk
EMd05phveJr0x/v20jZTcWS3tokP9gM4qXlTd2lZHLk279rkRuyR8G3CfEUc
90bIXDImtmOcvpFH/C+2XkyJePzgYbch4mlhthp+4rLP+7YqrYqjbag4sBAb
hba0HCemaX7wHPUFgHOfzLnXxPFrRHrUc+KZ3DsdD4mXGI0zrxOfP6bv6/hP
HDkCvxrK+gBsdaTx71svgXyz9y4+8waYr31UnbhZAuv9E7IsdgHo+rIJFLBJ
4IFuZr5uT4D+hcZ9yCmBsdxKcRbWAJZPLjAMu0qgtIFWYK4u2e/lOOO1PAm8
Gs7/6aEcwKMph6L5bgmMOHyjrZKf1B8YzGbmlsT2P10SCVsBKjQOrn3xkUQZ
3XdVS68NgON21i42CSlUKQnL7Sb+uO+qwj7irlfZ0dXErw/+3FBPLFWo6ppN
PFw7O8wuKYVmsr5q+4nvRD5uDCY23bdlhxmx4iOlW1Tiv4pH3q82GUCSvkz4
fikp9Dr/5+xD4pOJG0x2SkuhWmiCVRjx5lstIs+JExI+S115YQB0jKlax5Sk
UNTph/mrBgNQ1j2fp6kphX/2y5ZMUQ2A7VqQ7pK+FGaaSOnz1hkAVeSEMs1U
CuXtPLmu3TAAp4lDtaGZUmhwsXiy/ZQB1EvYf//8Vgpjz4rU39trAJ+Wq7gE
uaSxnVcwxMDCAOz4HJxsAqQxokXrZZy0AYzo9vFF35PG+V03iww+6sPDjw72
XpkyGHT7sjQPcfVwvngd8f3d26rnuvXh4+EMBv4sGcyOW6/VSXwh4NHQCeJn
i7FYQfyol69pgPhn937TDOJ9G2kVxqdl0M3I2gGI6Q08k5jPyGDlmqjnfJc+
2Oj0720lfvJj3reSmHLI2fVstgzudbip+qFTH1YfmMVq5cvgpV4W/cU3+vBr
x9HKsesy+CjowTG+dn3YJH569dotGcyv2PYLWvTB4bLEAbcKGUxKO0MXU6EP
qg33ZWqWZTCgQP2P1zl9uBzuUSFpI4s8t6qSx6P0oWiPiFZHgSx+HHA+KOKq
D67Faz2107L4XU/YhEFDH6q0+3w2Wcth/HuVqx7DenDfXHjbPUN5PLfenV+e
OHeNz0/RSB7dr7woZCDucLR/XEV8LTNe+NOQHuxdKdquYiyPkm+OF1cSH3bn
OvyA+KVfq0gy8Ytn1Z/VTOQxZfOisAKx62nxR5qm8hhZai/QO6gHz5Skb+mY
yWPTagclhVghjlaqby6PQQ7uOsr9euChflJ7j6M8Fv/XDn2f9cDYMWUga5c8
Vuyyl8zoIf0YPiql7pXHD8Xzf5S79KDOfPPVxXB5LMt74pNfowdSp4IH2Xrk
ceXJ5pcpOXogombhn2WsgOGyd11XD+qBu3jtq9xqBdzbfH7rorUeHJwXMK1g
V0Qju+S6aEk9kNSQSdlgp4iuRwuaX37RBVpVxD+Dt4oo/nBl/hbxbfPmlhji
/a5TYqnEya8PXL5H3OcW7xxEvOFAU8gosf6j64lm/3vf9IuOwDtFtIhwrRAn
loi4s9Wd2DRnav3oZ13wvP+09hUx478R79vEvqL3Dqp3KmLQDbXqfcT30rIk
/yOOatl1d7xHFzaxB4wyflTEjKYxurBuXZBRPbMr6LMiZtkduff7vS7Qa/Wn
tfQr4ib964/D3+nCio9SuNKwIjJZw6TrE10Q2xzP92abErJ4efkuFujCr+ZY
x0x9Jbw4KuDpkaILGHnp6cEwJawq8eKNPKALl85u90u/roSN7k+7DR114cN/
OpVDHUrYyc3++NxfHfDrKD18JU0Zv9wXhN9ndaBJI/XGAScVvNx1IbD6mA4w
BgplJyWo4FMlCq/lPh0oFM7zSC5TQcWZe0eqnHSAYex04uFuFVTYnBw9rqcD
3/eebPdhVMXc8IdbpiV1gEfHVc1CRRVdNv7XdXBNm9wnZWY1LqiiUO3v3KFe
bYjknjd/O6KKF/vy+T4QB+mpX54hjhcRvf2CWPH8iwnKqCoGZOQrPiRmafqh
r0fcu/X301vEV/tvnd9DHPVI2jifOPXbwkgK8Sujg64xxBtSRHM6iAutzfZ5
EN+eLdfjHFPF5PbqWC3iUuezP32JLf52bmX8pA0hl22NNSZUMdN6KL7jozYE
b09O3fpbFS9rdeOlbm0I/fPg0dgfVbzBVNDj36UNZo/8PzyfVsWaNcuH+s3a
8CzoxaFj29TQxsLj68Z6bbjC8G1Lrpwa1tOsuV7c1wa1foOqzdZqyBcSqxhW
og1nYoYOjgar4VD98hjjJW0oqgwLlExTw5/OQp5LxtqgfkDVYZeXOma5zTcX
/tSCuEdsHaWGGhjJdCnnvxwt+Pp2p2CGgSbKR0sLJBKvT5e5Ok/sW8N615M4
b99RriDQxOQ6Q00V4tXJk9c+EPOlv2pkId53yFTU2FATS7dcsxs5pwUPjF7c
ryI2Oj7mf5m4jX61K9tIEz9diIm2IdazFN8SaqyJ3jstk/6d1YLcO0aeliaa
mJ6Zmbh6WgvErrz0/mujiffqnu5fytAC25uqnUWumii2OA5zqVpwWymr0ctH
E5McFemnkrTAT7JTm3ufJg4siEDiXi3IFGndp0PTxFdLi/I3zLQg/lyTzlFe
LfweNfTJUkILDN49Ll89poUK2V6c8cxaYP6aKXymTwt3eArVKo1qwr2Dmx9z
mWqj3jZKUemIJig9qU19Y6aNzzmFEgWIrY0eXk2x0MZXm3Rc879rAuNrjlkd
K23clBwoxEpc3Pjz/F9rbZzkuzacNKwJdTX2h8tstZFzTsQzckgTBo56TXA6
amNM/Mcyn0FNWDNzi05z0ca12PJu6wFN6HD7tG3BXRsjg4J70rpJftC5/stx
2vgE6249bNUEhoc7P5Rd18bhP3FsXTRNYEu+DtIN2sjI7vDr+0NNyJyKO8n3
nfTja79NK0kTui94q8JZHVyd6xg1tdeEroAj9f3Gupi9f3B1nksThH6fUVpl
0MOWdoV48ykNGKgQKt90VQ+Xj8Wm0po0QHqIkrusqY8LHItO94iX5R7N6Gnp
45/vzgIFxD48XO6JxDy/0ydOE99s+fzsOXG17KXHx4jNzdcE1mvr48/Ck0n7
ifF6Yqo58Y2/G3gsiPeJbXdvI67avlglRpyTJybnqKOPfauOFgzEKg5PNnQT
I4clc/lLDdjQ4NbKbKiPt+9uz3J6oQH+4w8e6pjp42b7y+8Xn2tAmrV9c6S1
Pip6NXwrbNAAu7xi5jsO+rgtqvcM9wMNOHKef9IlRR9tbxQUxP+nAdsFg5j6
n+ljG2ds5atLGqBleczFbkofH18RdFvI1IDLvC/pyiQNkP7FaRm2BDKv1F/n
WT8DPDp/12NKWQOawnu2BFgDuj534lZdUgfzE4lvspoA+6S/iNz+rQ4WzsdN
zQYAvXpqgjcMqYOVpLuP3zIg3fG2QveP6hBb9vrKlx2GOPd0S8aFVnWwCXeP
rVc0RAv3rM9UVAfbU1LJ620MsdYgu6D3tjpYn66/3JVkiCVje/JLz6pDzwNf
U/96Q3QXyHcUjyG+Kd/SsGCI4XrnDBx91OETc7zdZnUjzGOwvSduqg7/eCRH
3A4bYa6nN9fDZTW4veJmPq9qjHWd0+GXiE+F7E83VjPGRwlcr44RL+XsaD9L
bOzWzuNL/F/HJY4vxCIeWyONiPscZnwk1Y2RcqL/pRhxvKXk3WhiZZZrB38u
qcEZmLBl1TDGSqacHTXEBgLsy7eIs2yoz44S/3eooEZf0xidLh1v01lQA0Yd
9d2a+sbYLFEmszqrBnYFrCfVTYzx1LknH+un1UAsWEZMy8oYHUXF3yZMqUHh
0nV7cDDGh5f7j3T3qsFFriWu1DPGyGs7cmWkUQ0aDgdzlrcZY6lX11r5XTUw
nv2U8ZrVBJ+rhJuL5qmBnrjhswUHE1SRF12ySVADfn8VJvd8E/K/bmOP1lID
jqD//PkDTLGa7tOd0XVqQGk6q6Sy3Qy5Ki6+fkN85pjdhURiywL6kcfEBvfV
F9uJM95xMRQSP3Mu8uPhMEMhk68C6cTlp3Jagom9pm10I4iLPBk1HhEzv0iO
BuL/BvbudNxhhlYHw8q3EbfLf/w3Qbz7C9PANzo1YJfynE7daYaX/FSr6P+p
wlhkck02rxneyNn4T2RVFU7mnvLKFTbD4KL0FpNlVZCeeDN7VdKMfB/22/cu
qsKfQofMUnkz3OW0LTNrRBVOuLX/Ywwl+Say0QnvVUFfKucGQ7kZxvfwB2vR
VOHu+9l/jyfMUO7Rnon6u6pwCBnC1OXNceN8vbfeKVVgGbAW5Wo0xw1R52j/
uakCq/OzgvA9FuiXc19gTEoVikbyV8Q3WeI2U6uJX8sqcKWcazMb1RKLJYZV
+4kTRsyFrIlLu72PvyU+PHtYK4U4xPFBUwPxgZgBJyRWvji+rYZY7mhm2CKx
7e1/niXEg0yRGSpoifZeoxOpxEMth17cJuZUtEoIIV4xDmPkpVnivLDkFhvi
ia7dlueIhbiNrogtqcBUiTwL70tL1Bjz+ru2oAIjzxQaypotkcHHe2fPvAp0
rwyHaHVYoqSIIlPVnAooX3jP3NppiWKD+jwCEyrA6hKuMkZnhW/vHA6N7VeB
+bqR1jcKVrhNY1tB3XsV+M1WuZLma4WOZSmOE00qYOLgv5PznBVqH48UY6xT
AbsdK2eTGqzwwfbWuNiTKmDE/GS3X501+huJVTwxUYF398M16d7YYC6z0OqZ
9SqQV+Xo1Ldii1Inqv4cIabfev+S/aotNg+PD/kSX7LkG6IRB6q1d1sQ91ak
KCmv2eJEmEezErFU2I+kYmK7rNO13MQOTyx6Of7Z4kia2Y2fjCqw19kuZ554
YLn4JJXYjM3Eo5fODmkdJf7niFkTZBTq19nh07dVA8/pVcCZL5z++iY7ZJoU
65mhUwERSvnOpO12aPJ3yVT8nzLMMP+I2MNrh4fLXsi4ryqDzIctLupixK06
6iazyvCiNPdJh40d3vsbWiD+Sxma8eGHkWg7vJ8hZrA2rAwVn9/cPHndDs/X
75ht+aIM3+dDuYpekf2bItpmbivD3zOxI+4f7bGxnH6nfqQyBKWXHrZOdMAf
Ge374jSVQY+PMrAo7IjHY/WEY1aVYMf7jUFXuxzxYf6W9cHE8oN5z5uJYw48
GfUgbmR/zb9A3DKr3WJJLDYmGC/e7YgPVPPvahMnRBT2uhDrSLRkyxB3PjHT
TiJeixhyYiXeJXV2pZ8YEn13Tq4oAY/soUbdj46oYqv/6S1xtvx09mVimwRh
l6JlJbAffH9C+7MjXqeLyTm0pAS0jTEGX/scsd2ML8dkUQluaaS8OTnoiOmn
5px2LCjBp5xSJckRR1R8fDVJ4acSuLmJX2Xd7IT8jHkblL4pgfj7xz73FZ2w
f8LQn+sDWVc+Zc3p7oQsQTEsY01K8GyLrb/lcSds8XE5fq1WCegnjny0/c8J
mRlczU3SlUDnoETynJMzVqyfDGdwVoKXZzpvLmx1wUl72TN3eJQA5Jt+1fa7
4C0te8984rB3//3Z+M0FJW+Ki50i7r65e86d+G1S9Z8w4vKC92u3iGf6/tZ6
El//sWHTDPGve6OppsRPS1Y5jQZcsERdm5ePuH8rvU4fsUm8z/0ZbiVgv7I+
JG7QBZMOuBi3EX9w21i0c8gFR6x/oAaXEvxlF9ZW+eGCjb4bXhVxkvl8hoRd
Jl1wzMnHlXWnEtz3jPU7OuuCTeIXw2I4SJ4L23zRsgsqGkefOMWoBAesja6r
abuiX7Vmm/U6JVAJbJOfNHPFAzcN5bavKcK5IuHgi86u6OM+XNKzpAgxgYMr
Wn6ueGizg/K1eUWQHS1gnwx1Rf6svK8lU4pws6Oi8GiyK97b6zX734QivD4U
dN7kmisa/jqzr+i7Iph0/5ZwfOCKjYkLD1o+KkL8l+A32j9dsfcu57Y3zYog
9z6VI0fMDS0fRZ6rrFWEqWd1iwF+bthco2UQXKEIL/PNZV5cc8OCPgPOoHOK
YDpxViOK2x1d6RMZaFGKoJTgGyl3wx1bmBvKQ10UIcHY7GiujAcavQmb2KOm
CL9CCwPtaB6YEeRQd2GHIqR5GLHs9PHEva9DTU4Rl9EF2hwijjM1bQsnbnWL
OvuWOOzzJ+fdxM+167rkfD1xKE36sxUx3QdDgSzikxYa/prEvy0YQseI5yde
h28nXqc5xFrs54lHWqzif3MogrnUg7rdezxR7F1dWjPxDa+YWIq/J/p9foru
28m8xvIXg0I8cZVb7cx3NkXY/7il+WmEJ/J0DE9GbVME/T+cO9hjPfHu9eOj
/7YogoPCaEL4CU/cPM/vuJ9OES6gF59KiydGnjw3M7OkAJcFjQr5PpF6cbNB
tlkFeDx+/yTbmCd+P/o7SGZSATjXr85wz3uiTJpfguEPBai0yVLVZvLCFplr
1gFfFSC/NJS+VtQLb/OeEI15pwAvE5cb84y9UPVLZV/8SwV4wfrLs83fC+m8
ZuyjnyqAe6twhd8pL3SfvO3onaAAXKe1euNFdqHBaL3DWwMF+BbBy3OjYxdq
3leseEKnAHEDb5veJXvjtbL83csoD1LtCa0a5rux9FTs3WMJ8lCT9+vJVk4f
lGayzl8VlAdH5zTXg2a+WC/UGPaVOOeW9eteYvnaVpN64vqcER1zc1/s7gjk
uU7sErylpoZ4q2f2VDzxnEOjnKCFLyq7WTR5E7NFr797mrhX9mskL7FF2dOq
vZa+WFpRw/1FQB4Gg0pe6lv54p7a1oarxIdnX41yWvviw+knY5x88rDrq5JN
vrMvbul+7pfLLQ+cf3qMub1JP+tjpLZQ5GGFWvG+ONAXxYz9jdJ3yEPPzG06
lTBfVFE3lZdYkQPbf1b0dxp9sV23+GrZshwICx08bP/SF0NuHaeXJf7h+lBg
9pUvWl7s9q9ckoPQs510V1/7YrzWnTpF4hjV9xTDFl/8XL2wtWZRDnLvvdg3
2uqLfvwZZY8X5ECpFS+ovvHFfI5Vybp5OTA9srXgVKcv8r+yzabNyYHjUcHk
d12+yBDL823kpxw0Xhux2jlPzve4Xx/9kBycvn38nCeLH85xNIVxfJKD8IzK
Xhc+P+QucI3ieSMHV3kp/Qnyfhh9N3ZH7iU5yH7jqGWb7Yce1+O+N/jJwb1a
7vzFaT8UshpxzpWQAxbfDaMCfnvQ5mjkgz8/ZeHglfYvB97vwVLBLfQN92Uh
upzt/WU7f7wl0bLxi7cs3G2VV+ykD8CA+fRXJetloeGN+oBAcwB6XAtZSCX+
cXHu6l7i+2oDUiHEBYXRHuXEv3HSy5p4z1cjzinifI28LDnivuA9PeotASh7
+V3tVmK93W+vxhMrScTyfGCUBd6JMskNrQE4qxt39BIxyryi5hKfo37s8iY+
NyvmI9AWgKWJmzk30MvCShV3ft67AMzueVVT/U8GCga60zd+DMAYVqZK71UZ
mKbu9vf8EoA7dhzYwLQsA0UZnT13BwLwboxbS9SUDPTezm06P0/yftnNfxiV
Ae+f5nmPWANxWcYqUrZPBlSsotO5RANxnbbIVEujDAzuXPjL7B+IMpFCpzjL
ZOBn6LLW+M1AHBJ+cW5rtgyUi1mqfxkKRNNuhl33o4htefWWJfbiP5k+72iQ
AWGPQOp/pXtxTfXvOB2rDAjNHivMVArC49btaNgjDYk7M/2ONQbhBU6JXMEi
aVD7MvzQ33cfhk9mfEreLw2bXhSnGDEFo3iaUtw0vzSkxza8dZkJxlDb/bM9
xKWt5Q/vENO3m0dQif9rU7xKNxuM4/Qt48XEFtdSk9yIJX7+Ccwgvu1VcfAu
8bOUur6DxNYSt7zp54Kxje36Oy3isKRvBpXEtcbbGhmJ+QP3yHvNB+N5hp01
b/ikgatDUpJpIRgnux+/qOORhpj8WTfaWjDyJymZl3FJg+DOoqnj60PwlbWY
dh6nNKgo860YsoQgf53q9cQd0hC17BW3cXsI3nEuNMilk4ahM15P2txDsEnt
x7j3ihREeZSYmO8NQb2KXi/RBSmIT1wJpEWFYLbg59M/pqWglDuUzSaR5HGe
Trg7KQX1naNx42dCkOFWRLbMqBRQxTvN/cpCMNVEIvpmnxQM9vu5irwMwfE9
rzi2dEtBxk1ZVbWBEHyg3uca2S4F4WsDxy6uhuDMiUofvkIp2KJ3JdIyfz+a
jY0sPo2UgmdvfPxzNA/gE2W/OjUjKZh88ft6zPcDuJl22y+BTQrUTKlvBApC
sSggK/tYvyRUoTVze0AY0rl1sFpekwR//ukrm48dxBNDfd3JbpKgEBpRa1YZ
jv1od2GCVRLsUXGsOTEC+9mZx98Rh9/rrmY+GYFaVr4GT4g9vI0STYmP+7tf
KCDWqBq0TyIGj8mxZOKK5sdCDcTskhJ6B4j/0Bpm14h/R3UPaxDLbz9THHcq
ApOY1mcxEt9blvWaI3ZvqlZ4xyIJ/J5FXFFJEfh24rH1m02SkHX3TZxlegRu
nJl+27ZBElgN2ZxFz0RgoucytZlJEroVXt6iPx+BCk/37HjFKAk3E+2ODOdH
YMfpi4t1dJLwTuZkQXUhWf/yI7lqRQKMa3nrRe9EYGpValPxggTccljlOVMT
gZqrjzF3RgIOfjp3nqE+Ajdcsjpa9lMCOMSDa06/icDtb0aCHg1LgAv9l1qb
wQiMNd198NkXCRBqP/PJZDYCvaJn1ss2ScCUvDmbglQkhmw0mfCqkoCH0XoK
bT6RmHf/7x+TqxJg4ufjqJYfiUJhWxpGkyXAb93StpQ3kVjJx2ny0lsCuoq4
2NK0ovDhFfet91Qk4OS/yyoRd6KQa7Vv+sJGCai+Eza+IHwIN4pxUvb2iYNI
/1nl38WHUF3/VP3manHQaZrsUpWPxv8iA0fvx4jDdV36lxd+ReOkoxw9r444
lLM+PsdLO4zXBalTh7aJw/K3PfbDu45gWrS9YhOzOBTP7Ovxij+C7IWM71n/
iUHfcWPqhutHcH/Arlu2q2LAznHFSqf4CDrxN6ycXhYDU7PGmKiyI8gz9Kmn
dVEM5lI1bCrvHcHlwbd8FnNicPZwJ6Nq3RH8ulMq8vlfMdBa/lHW9voItm2g
e6s9KQZZNRURsV1HkP/GLo2qCTGY4WM/qzF4BCtAnX+uRQz+ueeMHveKwYhJ
w9asMjGQXnEp6/kUg1XZ/Q/3pYnBiqbnNfo9sWi3zUP3eKAYVLCuPez4E4vb
y7mTnoMY2EYxyYlnHkXeuZ3D2lvEwCThTJD+wThkmed+O/BJFJ71G03YhhxD
+x0PNNOKRaEuA22Hj8djuLJ72vR+UejfsbhZvyYBvXqGuUYUROEPq9hQ1OYT
mBao7P5soyisje+efzB3AreEyu9yI9ZvyeqTXjyB2mox7n83iELNCdC7uXwC
s80322QT3xr05KCsnUAp6R+a0sQz8itV5nSJ2Biwlf8VsyjkqvLnJ61LRNH7
Yz2rTKKwrVBteZkhEQtedkWrEdf6GDodZkrEYx0tU6HrRcH/28urkxsSUUiz
xDRnVQRuKe7h0RVKxNB1mTfDibXO5PIVECt6FK/YEp/pviROJ5yI5fJ/3GSJ
rQ3V1f2JeWMi7m8ini0MtXlBjCKiG3+siMCb17oh4iKJOC3498ktYt/3Hg/G
ib/Jn9nrT5zK/J3rnmgiqvTPbBEg/sg2dvmQWCJuPnd1JX5RBNIj9OzF5RLx
ealT6ae5/+WVxAypJuIwU9A2tRkRUM7dLVeum4h8e3lUzk6JwO6LvzITTBKx
1kOAv71bBA6tb2jemZeIqY93rkuuFQH1v9FhzuOJ+MSmd7z8hgjMSO4pqzA5
iYd4z3PpJomAydNDHBUlJzGu+OOAdJAIHCsdaRjbdAqZ36sortMVAZfMGINN
t0+h8s7utz7bRMCtoJ+V1TkJmTfdCuIdEgYNrXOyx9mS8dbFVmmWB8JwouTU
tfDvyTji2ZexcEoYHms7fyzoTMHvm+L2FNkLA9+Os1llX1PR5fzNu1QuYbi8
zm/OnSUdxdsCZyqJ57Kzm2uI79D/1LlB3MQ/e3krazpeU9FIOktce7sz7ADx
M2+zlhPER7wkTJuIqce42CKIHYKnBUS2pOPdG+YFDsQeMbl9vcSuqSnSSsSj
U+zl57emYx7f+4dsxLkBh1KstqXj6Wrp6W5OYZgq/rwxnjMdW1pcOq/uFAbv
pTq6Gv507Hbd5Oy3QxiMbvJETIql4/RthsOiHMLgd4nJR0kuHb273ik8ZRaG
daP/JBaOpCPPYH2T5nphYKJzGlxNScdBukddj+iFgeOYfD93Xjr2Zbq7q9AJ
g7Ggn7N9SToKcoZ5V64KgWNoSttkVTq6HLVZJ7ksBO8OhR49ien4vfe8UeGC
EOzl6b4s1Z6OyZI3+TjnhOD8/P6osd50bDvy4CLdlBC5f9/cXT6Xjv7zGd7D
E0IgfVc6qI09A78eqvR4PiIEwzNiL20VMnDnqmbslQEh2C+u9FzJJgN1k4dy
ApqFQG/EiP/wxwwM2brer+S+EFRlmscrhmZizdJsoPNFIfjgmRuSuDkLBc5r
MAUlCIGgz+yr0kdZ+H2Z2++tvxCcCB4+xRt+GqWuqjR6GgqBWOjXu9v3nsGm
a/sbH/MLgYcKm+f6w9n4n6nfx+YlQdh0qvCyY/FZPMt68UtIlyDsr/jFezfu
HG4Y1K7bXykIV9e5FHzXzEEj0cGS/BRBEIJ0hvPbziNL/IB6g78gBPkXcnJ8
PI+d9YOXffQFQaDQImP0YS5KVGam6VIEgW9koPNz1QXUSM88pL1OEFQ0Rn4+
dM7D7zpLsyt0giAvWrkQ4ZqHSj8OHELiTT/7fWXd81A8pW/iJLGuwH2RMY88
jGV09DUhVjila1LilYcZu563MxGXjBQ1+Hnnoe8+RxPOfwIwcDsi3Mk3D/v0
nFsF1wRgiL8rXM8/D7utyxSlVwVA/vfcU6m9eShUd2rSfUYA6rOqWjkT8/Df
BHdy3IQA2DVnXo++mofm4ka0nEEBOEQpMjN+TPoJVex0aRcABT2BH++X8vCX
z9neD48FQICl0ErAMB8dXSbEthYJgHnURIprZj6+7uJ/SXdaAC5obVq8052P
eh4HNvzZJwDPrpTRh3lcxCzPMFVWYwEQbRcd/jx0ERdqmQws+ASAw8Q4Tyru
EuqKCwmdneOHjLmx2ae8l3FmA0NMewc/ZGmqCci3X8ba/L/RIjf4wTef9X5s
5RXkuFk41xzGD580OJh6Sq9iF/QHndXmB4NdfWZfaNfQfpFhRHM9P4Q21AWZ
r1zHtBfnHpxo54PE5ajHCf43MPOXwD3WXD4Q3Riam3+8ED+k5jcbBfDBZOXs
bRO1m7g8HXXTQYkPEnJS838yFOFY2eDKxAovnJznCBycLMJDIcZ0i295QZh+
X2bhq2Lk0de2/lfEC/tiKx2TnpZgq4v4lidRvMC0x/Tsj45bqNSv5eNixQtP
HHz18lv+w4PTunmbBXkh98PYkYOjtzEs3WnxyjQPOMRRrEXkylCJ1e3ChQ4e
0C/PnLrofAf/Ro65tt7mgVB1G3Gnm+V44Yr2broTPFAGwnaVAhUYuBi3IL+b
B6RZD7wXiK1EUSuxT3VaPOAd8yfX5t89rFv4+vwgBw98KPrD6/7tPj47mctw
d5Yb/Gd3XOG4U4UwXFQb0sUN9y44ljefrcaarFc8ETXckM5yMe70pRpsP0fd
nneRGzbmKmelpjxAaYNxXa84bgj5ZdGjdOEhtr82Pdjrxw2v2o9tk8t7hEr6
XRl8ZqT+bVLQ3mePUXDPj6wZKWJBlREz1qdYrNQzn87ODVUvfAo2GT3Dljxj
/clFLvjKNL3/RkktjjzeWHdymAvGNjy94DxXhwyveRXpO7jgdYJLD1scFT/6
rzaZPuKCH19dDr3lp+Hbx4EjWMQFndqKdw9M0DDha+64WjYX5OKWzcw9DXhE
zFnncDwXNJmpv+h58hzVtMapzSFcUP30wYHmukZU27N2m8WNCyaYWU5w/36B
NYy3zy2ZcoHA7uYTVeteYeN7gfKNalzwn1ot+y+jJhz6rbQrSZwLmPITF+IP
vcaMLLFWVU4u4Gg+ahDV3YwKI0z2HRu54CqTWOQx+Va0L9pTU75MAVE9b69W
WhvqGfpH2k9SgId5JMHMvAN/2E9PGw5SQFdku9/7DW8xZPvF49+7KZCZa3Oo
Z+QtCq7xPRxsoYCC4p3Uwz/f4T+vbKdYGgX+TT14c/NHJ178804y6iEFZK84
Mgjs+IDby3oXx8sp8OfaO68W9S50O3KetfMmBbKpGWZfs7uRfomSI3CZAnrz
NxLjP3/ELccX+4bPUuAHC/s12+BPuD+1WWkxjQI19QN5VaO9qG0+syv7BAU4
xWT/KtZ8wa/5aUresRSw/VB1/+vBPrRhHzpSE0EB39rJB9eMvqG1aRCH/H4K
wKWDSQdMBrDNLc1KO4ACb1omeLLiB/GxtWCq624KmF1reHaybAinXPgpm9wp
0PX8c9EY53fUKfLweOZIgVVtXJqKHcH1PjOmm20oYMq+JcpOagxdvG0TTc0p
8FV/6vS55h9Y667nLWFEgcTI4p0FLRO49+MU+4AeBfJ89QXEnvxCj+hoOkst
CnhpsD512PIHj+9+ZRCrRgEtqW/VxapT+Hlb1eQuJQrcNgpxulnyFwf6XlvN
y1FAMdc2bW79DLKd1FywkaaQ+8ylh3aNszjsWJdiLUEBTzn7iGMH5zE58MTf
jaIUkGf5qfvfmUWs9JuxCBCiwHTg1uNc+cvYytH49CQ/BWqfW6yZKK8hq1PL
hBwvBXKseW8MetDRNgR5i5ZwUSDIlmW+cX4dbSb0U91VTgosHeBM80lmoNkN
jSzv2UGB8L62OpYz62n+pTxL17dTYLSusVrqODPtY5vT7F02CsTOnxfdv30T
bdZq+bX4NgoM3VlLGs5gob09PlMas4UCbkN0/uu/bqVFXD4gL8VKAfuEpr7q
JDZalVNR5sPNFMj4+PPa9L3ttLeZ3MyXN1HgenKgRQttB6190/SA10YKVD09
qD5VQqHVb333b/8GCpzKeaqREcBDK2188NybmQKlbp6v9B0FaM9UpOY8iEt+
JVOS9gjQzuSUSLgSB/x3SPhNpACt8pWIuyPxAfq6CtVTArTcB8XJtsR3nJRX
a84L0BJUhe5bEs9tLXSxLRagcXRtYTAitn896fLqhQAtnvbBVvt/+Z3P998Z
EaDRN3qcUyZWS3P4lcAoSPt0YdpqiIkCx7cyv/xeJ0jzH/lhfo64FG27bp8T
ou1/xPlXk9iyuOancZowzTh/XfqX9RQoF4n+drRchHbIoM05mHjhIKXe1EmM
Zrbatv8HIwX6U1i7HI9K0DryAzyOEFewVhY1dUvRQhK6pliIi9afjTOPkaUZ
vK1OvshAgQR76Tt0rIo0KKis0SU+pSrZGvhGiXahfTm/m54C1YdSPqg4qNK+
SVQaZhJ7rTtX2VCtTqssG79pTCyvEDf/5YgWze3yuiZGYgavZZ83Z3Vpzje9
PrWso0CZwYddCTuA9m68hSWfOH1Eun5C1ohm8qG4ay+xq8bWv8M3TGirV/es
aBHb5amyGJ80p9n/5VVnJ940nfKIY9yKpjsnZ/SbjgL7/3sp8nrRjjZwTOZb
O/G3+Oq9aT8daVmVjZ33ice3HK8L6nOhHSh705dP/PFEQLrnYQ8ah/aZ1hPE
6sZXet/1e9O+JaX4HyAWa825ZCm/h1bgcjrckzjs6ihfd2Egbdv8U5olsb7M
Vq3jDCE0GYVgcV3icJOBGenyg7T/A0wal/M=
      "]}, {Automatic}],
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.799476821873794*^9, 3.799476859610416*^9}, {
   3.7994769041120167`*^9, 3.799476927622757*^9}, {3.799476965756878*^9, 
   3.799477019907857*^9}, 3.7994797263410482`*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"1aa5b403-a20d-453f-bf5a-ca2767d4384d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"tMax", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r1", "/.", "sol"}], ")"}], "[", "\"\<Domain\>\"", "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "2"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.799477029095492*^9, 3.799477054431777*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"10fcc3e0-c017-4784-a461-b6fb6678db9b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"r1", "[", "t", "]"}], "/.", "sol"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "tMax"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.799476924048256*^9, 3.799476956689229*^9}, {
  3.799476991061139*^9, 3.799477023244832*^9}, {3.79947705646642*^9, 
  3.79947706009979*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"18ec21e7-e337-4c30-8e89-286f666767b5"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVjnk81Ikbx6Vs1iZHtyiVc0OhXIN5HjPDzPh+vwwzY7ZiHUW/2KjEOiIR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       "]]},
     Annotation[#, "Charting`Private`Tag$30954#1"]& ]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 6.095869056029609},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4.01336431105909*^6}, {6.095869056029609, 
    99.99999948777064}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.799476956948107*^9, 3.799477017255364*^9}, {
   3.79947705770817*^9, 3.799477060484149*^9}, 3.799479726401988*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"ab4eabbe-54ba-49e1-a012-1cca999b1563"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1427, 910},
WindowMargins->{{Automatic, 169}, {Automatic, 173}},
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (March 18, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"91bcfa40-00a3-4483-8adb-4298a58ee246"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 225, 5, 160, "Title",ExpressionUUID->"98738028-b722-46dd-a601-c344155c524b"],
Cell[808, 29, 332, 7, 35, "Text",ExpressionUUID->"ccab6398-4aba-4ca7-810d-52534794e246"],
Cell[1143, 38, 433, 7, 73, "Input",ExpressionUUID->"a2ce0865-9be5-41cd-9d78-8b8b23bb3143"],
Cell[CellGroupData[{
Cell[1601, 49, 176, 3, 67, "Section",ExpressionUUID->"1e57007e-8a08-40ed-9499-25292743807d"],
Cell[1780, 54, 466, 9, 58, "Text",ExpressionUUID->"86d5b6dd-fce0-4b36-bcdd-e505136f5f56"],
Cell[CellGroupData[{
Cell[2271, 67, 440, 10, 52, "Input",ExpressionUUID->"0532d9d7-6ea3-4947-841a-29224e07df09"],
Cell[2714, 79, 489, 9, 34, "Output",ExpressionUUID->"ce9ee112-7053-4034-bcdf-bcc246420191"]
}, Open  ]],
Cell[3218, 91, 196, 3, 35, "Text",ExpressionUUID->"e0bc3f5b-3ec2-4f67-af4f-053d3cddb66d"],
Cell[CellGroupData[{
Cell[3439, 98, 655, 15, 30, "Input",ExpressionUUID->"ef018f77-ca6c-41b3-8d69-ef1a2c963645"],
Cell[4097, 115, 430, 8, 34, "Output",ExpressionUUID->"beb09532-ca62-4f4f-bb39-b0b54da9f388"]
}, Open  ]],
Cell[4542, 126, 212, 5, 35, "Text",ExpressionUUID->"9f0cb153-e2b9-4ae3-9f38-c2ae04d4628a"],
Cell[CellGroupData[{
Cell[4779, 135, 437, 8, 52, "Input",ExpressionUUID->"8dd59a04-f7cc-4b17-b58b-2109a0b47a53"],
Cell[5219, 145, 698, 13, 37, "Output",ExpressionUUID->"cd84a8e7-2c60-479d-bca8-d5ae7327fa76"],
Cell[5920, 160, 546, 12, 34, "Output",ExpressionUUID->"c052eafe-e4e5-4456-bbcf-453bff821f73"]
}, Open  ]],
Cell[6481, 175, 212, 4, 35, "Text",ExpressionUUID->"eb4a6526-2368-4911-bdf0-e1a58b13f817"],
Cell[CellGroupData[{
Cell[6718, 183, 430, 9, 30, "Input",ExpressionUUID->"c8f01f6b-13f6-46a9-8832-0d59c304e29f"],
Cell[7151, 194, 1016, 19, 60, "Output",ExpressionUUID->"84251bac-173b-4c51-a4fb-c32fa8499f49"]
}, Open  ]],
Cell[8182, 216, 241, 6, 35, "Text",ExpressionUUID->"5e224812-56d7-42d7-9177-1e0ed892ca70"],
Cell[CellGroupData[{
Cell[8448, 226, 544, 12, 52, "Input",ExpressionUUID->"bcff1c4c-e04b-43c5-a7a6-e9239f7196f5"],
Cell[8995, 240, 287, 4, 34, "Output",ExpressionUUID->"8c1ddc38-bee4-4c94-a7f7-12d224927aee"],
Cell[9285, 246, 286, 4, 34, "Output",ExpressionUUID->"e2c2b8db-8727-4d5e-9c5e-91e34c0be388"]
}, Open  ]],
Cell[9586, 253, 337, 7, 35, "Text",ExpressionUUID->"c73ac5df-fd18-4be2-a6a3-ca1cbf9c8969"],
Cell[9926, 262, 549, 13, 30, "Input",ExpressionUUID->"7da7b80b-e208-44eb-9c5d-90510f77f92a"],
Cell[10478, 277, 489, 10, 30, "Input",ExpressionUUID->"c459596b-9c5a-4530-af12-5d23cb65b910"],
Cell[CellGroupData[{
Cell[10992, 291, 524, 10, 52, "Input",ExpressionUUID->"87e87705-4683-4ed9-ae05-568eeee0faa5"],
Cell[11519, 303, 1279, 26, 37, "Output",ExpressionUUID->"f7fdd751-45be-4c87-8bf0-593e91e8f2fa"],
Cell[12801, 331, 584, 11, 37, "Output",ExpressionUUID->"8f9eb1dc-09a2-4edb-b870-030d09f4f0c8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13422, 347, 406, 9, 52, "Input",ExpressionUUID->"32cc2fc0-84ce-4612-bf5a-783c872c95c0"],
Cell[13831, 358, 847, 18, 34, "Output",ExpressionUUID->"a70c34eb-71fd-48c6-9fef-1b67d691ce97"],
Cell[14681, 378, 477, 10, 34, "Output",ExpressionUUID->"95b666bf-737f-478e-932d-eca96f9baada"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15195, 393, 453, 10, 52, "Input",ExpressionUUID->"c414cedd-f8b4-4260-b827-226760eed17f"],
Cell[15651, 405, 554, 10, 34, "Output",ExpressionUUID->"819c5761-82f0-49e9-934a-d126f3b5f405"],
Cell[16208, 417, 449, 8, 34, "Output",ExpressionUUID->"ada2e496-3099-4d8c-b4a1-23c499dcdefe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16694, 430, 428, 10, 52, "Input",ExpressionUUID->"8b378193-0e0e-4f22-85b9-ba1584ad7cb6"],
Cell[17125, 442, 431, 7, 34, "Output",ExpressionUUID->"d0bdee9e-1bad-42e2-bda4-785065c6c4f4"],
Cell[17559, 451, 327, 6, 34, "Output",ExpressionUUID->"3117fb96-8203-4363-a1f6-14b1dc6f8274"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17923, 462, 407, 9, 52, "Input",ExpressionUUID->"c6b04ef8-8f1e-45ad-87d5-465cb104f7af"],
Cell[18333, 473, 434, 8, 34, "Output",ExpressionUUID->"7c46805b-eb92-41aa-97a2-0f8e5f87206f"],
Cell[18770, 483, 343, 6, 34, "Output",ExpressionUUID->"9e92c858-acc3-4eaa-a15c-9910cd3f622b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19150, 494, 427, 10, 52, "Input",ExpressionUUID->"b2631fe9-4782-4e5d-a810-9d8f24f05ad9"],
Cell[19580, 506, 429, 10, 34, "Output",ExpressionUUID->"f1acdad9-8309-4c92-aa4c-bcb63138a541"],
Cell[20012, 518, 339, 7, 34, "Output",ExpressionUUID->"335d667f-353b-4fac-9758-73de5d7fefbc"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[20400, 531, 164, 3, 67, "Section",ExpressionUUID->"13832df6-7e2a-4393-90f9-cc1f9eb54ff3"],
Cell[20567, 536, 516, 13, 52, "Input",ExpressionUUID->"67a1bef5-8c06-463e-8b16-1a513da0c55d"],
Cell[CellGroupData[{
Cell[21108, 553, 776, 20, 30, "Input",ExpressionUUID->"d14b9fd5-6ab1-48a9-a338-1bcf0405ed08"],
Cell[21887, 575, 16633, 293, 511, "Output",ExpressionUUID->"05fe2498-ccd8-4983-b3fa-88e034180211"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38569, 874, 211, 4, 67, "Section",ExpressionUUID->"3cdc1f2b-6703-47b5-8677-ad3891cc2cd7"],
Cell[38783, 880, 264, 6, 35, "Text",ExpressionUUID->"a5d2a645-960b-4a7e-b21e-670e2df51fde"],
Cell[39050, 888, 211, 3, 30, "Input",ExpressionUUID->"e1362d04-6095-4b36-90d9-c4fc02e76ece"],
Cell[39264, 893, 370, 8, 30, "Input",ExpressionUUID->"a6155055-7685-4371-8e45-7ceac2977d6c"],
Cell[39637, 903, 390, 9, 30, "Input",ExpressionUUID->"fdf20be5-f686-4587-a781-9b73ae40afd5"],
Cell[40030, 914, 281, 6, 30, "Input",ExpressionUUID->"5958ba11-4f3a-4648-8314-8be9300d722a"],
Cell[40314, 922, 363, 8, 35, "Text",ExpressionUUID->"6759d3f5-be33-4de4-adec-02087f305900"],
Cell[CellGroupData[{
Cell[40702, 934, 994, 20, 94, "Input",ExpressionUUID->"ddd89545-0ccd-4a8b-9188-8502e2d03afd"],
Cell[41699, 956, 32579, 758, 621, "Output",ExpressionUUID->"75ad85bc-03d6-4954-9c11-8c419256d07a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74315, 1719, 193, 3, 54, "Subsection",ExpressionUUID->"d106a704-b217-4377-8d0b-8a6e13da87df"],
Cell[CellGroupData[{
Cell[74533, 1726, 293, 5, 30, "Input",ExpressionUUID->"9f512d06-942d-4d51-9eab-6a2837ffdca2"],
Cell[74829, 1733, 14749, 292, 63, "Output",ExpressionUUID->"fc6ac8bd-99f2-4a34-9522-52ff7ffd1a17"]
}, Open  ]],
Cell[89593, 2028, 725, 23, 40, "Text",ExpressionUUID->"b26d7909-87c0-4dde-aaa0-5f5274a3c52a"],
Cell[90321, 2053, 416, 11, 30, "Input",ExpressionUUID->"44185acc-087c-4772-a928-35c68f9f13ae"],
Cell[90740, 2066, 486, 11, 30, "Input",ExpressionUUID->"c9471b16-9303-4035-bd63-2fe4944d4451"],
Cell[CellGroupData[{
Cell[91251, 2081, 881, 22, 33, "Input",ExpressionUUID->"9062313f-5798-41f9-b942-4352abd08ad8"],
Cell[92135, 2105, 480, 11, 24, "Message",ExpressionUUID->"18d8e0ca-dac2-48a5-9cb1-675822290d3a"],
Cell[92618, 2118, 39243, 693, 70, "Output",ExpressionUUID->"1aa5b403-a20d-453f-bf5a-ca2767d4384d"]
}, Open  ]],
Cell[131876, 2814, 395, 10, 30, "Input",ExpressionUUID->"10fcc3e0-c017-4784-a461-b6fb6678db9b"],
Cell[CellGroupData[{
Cell[132296, 2828, 441, 10, 30, "Input",ExpressionUUID->"18ec21e7-e337-4c30-8e89-286f666767b5"],
Cell[132740, 2840, 4979, 100, 236, "Output",ExpressionUUID->"ab4eabbe-54ba-49e1-a012-1cca999b1563"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

